*** How Does the Dramatic Rise of CPS Nonresponse Impact Labor Market Indicators? 
*** Bernhardt, Munro, Wolcott 
*** Journal of Applied Econometrics 
*** 2023 

*** Attrition and LF status by MIS.do 
*** Creates data used in Table 1: "Selective Response Behavior"
*** See code chunks starting on lines 413, 467 ,874, 930 for specifc variables 

*BLS versions of the variables are just a robustness check to show BLS weigths don't fix the issue

cd "$IS_dir"

use "Data/eight_panel_complete.dta", clear

gen Emp1=1 if status1==1|status1==2
gen Unemp1=1 if status1==3|status1==4
gen NILF1=1 if status1==5|status1==6|status1==7
gen Sample1=1 if status1>0

*Find unemployment rates etc. for responders in MIS 1 and 2, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_1=total(Emp1) if HRINTSTA1==1 & HRINTSTA2==1
egen Unemp_Res_1=total(Unemp1) if HRINTSTA1==1 & HRINTSTA2==1
egen NILF_Res_1=total(NILF1) if HRINTSTA1==1 & HRINTSTA2==1
egen Sample_Res_1=total(Sample1) if HRINTSTA1==1 & HRINTSTA2==1

*do the same but with BLS weights
egen Emp_Res_BLS_1=total(PWCMPWGT1) if Emp1==1 & HRINTSTA1==1 & HRINTSTA2==1
egen Unemp_Res_BLS_1=total(PWCMPWGT1) if Unemp1==1 & HRINTSTA1==1 & HRINTSTA2==1
egen NILF_Res_BLS_1=total(PWCMPWGT1) if NILF1==1 & HRINTSTA1==1 & HRINTSTA2==1
egen Sample_Res_BLS_1=total(PWCMPWGT1) if Sample1==1 & HRINTSTA1==1 & HRINTSTA2==1


*Share of 1 and 2 responders by LF status

gen Emp_Res_Rate_1=Emp_Res_1/Sample_Res_1
gen Umemp_Res_Rate_1=Unemp_Res_1/Sample_Res_1
gen NILF_Res_Rate_1=NILF_Res_1/Sample_Res_1

*same but with BLS weights
gen Emp_Res_BLS_Rate_1=Emp_Res_BLS_1/Sample_Res_BLS_1
gen Umemp_Res_BLS_Rate_1=Unemp_Res_BLS_1/Sample_Res_BLS_1
gen NILF_Res_BLS_Rate_1=NILF_Res_BLS_1/Sample_Res_BLS_1

*Find unemployment rates etc. for responders in MIS 1 and TypeA 
* MIS 2, but define rates as share of sample, not traditional definition

egen Emp_TypeA_1=total(Emp1) if HRINTSTA1==1 & HRINTSTA2==2
egen Unemp_TypeA_1=total(Unemp1) if HRINTSTA1==1 & HRINTSTA2==2
egen NILF_TypeA_1=total(NILF1) if HRINTSTA1==1 & HRINTSTA2==2
egen Sample_TypeA_1=total(Sample1) if HRINTSTA1==1 & HRINTSTA2==2

*same but with BLS weights
egen Emp_TypeA_BLS_1=total(PWCMPWGT1) if Emp1==1 & HRINTSTA1==1 & HRINTSTA2==2
egen Unemp_TypeA_BLS_1=total(PWCMPWGT1) if Unemp1==1 & HRINTSTA1==1 & HRINTSTA2==2
egen NILF_TypeA_BLS_1=total(PWCMPWGT1) if NILF1==1 & HRINTSTA1==1 & HRINTSTA2==2
egen Sample_TypeA_BLS_1=total(PWCMPWGT1) if Sample1==1 & HRINTSTA1==1 & HRINTSTA2==2

*Share of 1 responder and 2 refusal by LF status

gen Emp_TypeA_Rate_1=Emp_TypeA_1/Sample_TypeA_1
gen Umemp_TypeA_Rate_1=Unemp_TypeA_1/Sample_TypeA_1
gen NILF_TypeA_Rate_1=NILF_TypeA_1/Sample_TypeA_1

*same but with BLS weights
gen Emp_TypeA_BLS_Rate_1=Emp_TypeA_BLS_1/Sample_TypeA_BLS_1
gen Umemp_TypeA_BLS_Rate_1=Unemp_TypeA_BLS_1/Sample_TypeA_BLS_1
gen NILF_TypeA_BLS_Rate_1=NILF_TypeA_BLS_1/Sample_TypeA_BLS_1

****************************************************************************
*************** Repeat process for MIS 2 to 3

gen Emp2=1 if status2==1|status2==2
gen Unemp2=1 if status2==3|status2==4
gen NILF2=1 if status2==5|status2==6|status2==7
gen Sample2=1 if status2>0


*Find unemployment rates etc. for responders in MIS 2 and 3, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_2=total(Emp2) if HRINTSTA2==1 & HRINTSTA3==1
egen Unemp_Res_2=total(Unemp2) if HRINTSTA2==1 & HRINTSTA3==1
egen NILF_Res_2=total(NILF2) if HRINTSTA2==1 & HRINTSTA3==1
egen Sample_Res_2=total(Sample2) if HRINTSTA2==1 & HRINTSTA3==1
*do the same but with BLS weights
egen Emp_Res_BLS_2=total(PWCMPWGT2) if Emp2==1 & HRINTSTA2==1 & HRINTSTA3==1
egen Unemp_Res_BLS_2=total(PWCMPWGT2) if Unemp2==1 & HRINTSTA2==1 & HRINTSTA3==1
egen NILF_Res_BLS_2=total(PWCMPWGT2) if NILF2==1 & HRINTSTA2==1 & HRINTSTA3==1
egen Sample_Res_BLS_2=total(PWCMPWGT2) if Sample2==1 & HRINTSTA2==1 & HRINTSTA3==1

*Share of 2 and 3 responders by LF status

gen Emp_Res_Rate_2=Emp_Res_2/Sample_Res_2
gen Umemp_Res_Rate_2=Unemp_Res_2/Sample_Res_2
gen NILF_Res_Rate_2=NILF_Res_2/Sample_Res_2
*same but with BLS weights
gen Emp_Res_BLS_Rate_2=Emp_Res_BLS_2/Sample_Res_BLS_2
gen Umemp_Res_BLS_Rate_2=Unemp_Res_BLS_2/Sample_Res_BLS_2
gen NILF_Res_BLS_Rate_2=NILF_Res_BLS_2/Sample_Res_BLS_2

*Find unemployment rates etc. for responders in MIS 2 and TypeA 
*MIS 3, but define rates as share of sample, not traditional definition

egen Emp_TypeA_2=total(Emp2) if HRINTSTA2==1 & HRINTSTA3==2
egen Unemp_TypeA_2=total(Unemp2) if HRINTSTA2==1 & HRINTSTA3==2
egen NILF_TypeA_2=total(NILF2) if HRINTSTA2==1 & HRINTSTA3==2
egen Sample_TypeA_2=total(Sample2) if HRINTSTA2==1 & HRINTSTA3==2

*same but with BLS weights
egen Emp_TypeA_BLS_2=total(PWCMPWGT2) if Emp2==1 & HRINTSTA2==1 & HRINTSTA3==2
egen Unemp_TypeA_BLS_2=total(PWCMPWGT2) if Unemp2==1 & HRINTSTA2==1 & HRINTSTA3==2
egen NILF_TypeA_BLS_2=total(PWCMPWGT2) if NILF2==1 & HRINTSTA2==1 & HRINTSTA3==2
egen Sample_TypeA_BLS_2=total(PWCMPWGT2) if Sample2==1 & HRINTSTA2==1 & HRINTSTA3==2

*Share of 2 responder and 3 refusal by LF status

gen Emp_TypeA_Rate_2=Emp_TypeA_2/Sample_TypeA_2
gen Umemp_TypeA_Rate_2=Unemp_TypeA_2/Sample_TypeA_2
gen NILF_TypeA_Rate_2=NILF_TypeA_2/Sample_TypeA_2
*same but with BLS weights
gen Emp_TypeA_BLS_Rate_2=Emp_TypeA_BLS_2/Sample_TypeA_BLS_2
gen Umemp_TypeA_BLS_Rate_2=Unemp_TypeA_BLS_2/Sample_TypeA_BLS_2
gen NILF_TypeA_BLS_Rate_2=NILF_TypeA_BLS_2/Sample_TypeA_BLS_2

****************************************************************************
*************** Repeat process for MIS 3 to 4

gen Emp3=1 if status3==1|status3==2
gen Unemp3=1 if status3==3|status3==4
gen NILF3=1 if status3==5|status3==6|status3==7
gen Sample3=1 if status3>0


*Find unemployment rates etc. for responders in MIS 3 and 4, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_3=total(Emp3) if HRINTSTA3==1 & HRINTSTA4==1
egen Unemp_Res_3=total(Unemp3) if HRINTSTA3==1 & HRINTSTA4==1
egen NILF_Res_3=total(NILF3) if HRINTSTA3==1 & HRINTSTA4==1
egen Sample_Res_3=total(Sample3) if HRINTSTA3==1 & HRINTSTA4==1
*do the same but with BLS weights
egen Emp_Res_BLS_3=total(PWCMPWGT3) if Emp3==1 & HRINTSTA3==1 & HRINTSTA4==1
egen Unemp_Res_BLS_3=total(PWCMPWGT3) if Unemp3==1 & HRINTSTA3==1 & HRINTSTA4==1
egen NILF_Res_BLS_3=total(PWCMPWGT3) if NILF3==1 & HRINTSTA3==1 & HRINTSTA4==1
egen Sample_Res_BLS_3=total(PWCMPWGT3) if Sample3==1 & HRINTSTA3==1 & HRINTSTA4==1

*Share of 3 and 4 responders by LF status

gen Emp_Res_Rate_3=Emp_Res_3/Sample_Res_3
gen Umemp_Res_Rate_3=Unemp_Res_3/Sample_Res_3
gen NILF_Res_Rate_3=NILF_Res_3/Sample_Res_3
*same but with BLS weights
gen Emp_Res_BLS_Rate_3=Emp_Res_BLS_3/Sample_Res_BLS_3
gen Umemp_Res_BLS_Rate_3=Unemp_Res_BLS_3/Sample_Res_BLS_3
gen NILF_Res_BLS_Rate_3=NILF_Res_BLS_3/Sample_Res_BLS_3

*Find unemployment rates etc. for responders in MIS 3 and TypeA 
* MIS 4, but define rates as share of sample, not traditional definition

egen Emp_TypeA_3=total(Emp3) if HRINTSTA3==1 & HRINTSTA4==2
egen Unemp_TypeA_3=total(Unemp3) if HRINTSTA3==1 & HRINTSTA4==2
egen NILF_TypeA_3=total(NILF3) if HRINTSTA3==1 & HRINTSTA4==2
egen Sample_TypeA_3=total(Sample3) if HRINTSTA3==1 & HRINTSTA4==2
*same but with BLS weights
egen Emp_TypeA_BLS_3=total(PWCMPWGT3) if Emp3==1 & HRINTSTA3==1 & HRINTSTA4==2
egen Unemp_TypeA_BLS_3=total(PWCMPWGT3) if Unemp3==1 & HRINTSTA3==1 & HRINTSTA4==2
egen NILF_TypeA_BLS_3=total(PWCMPWGT3) if NILF3==1 & HRINTSTA3==1 & HRINTSTA4==2
egen Sample_TypeA_BLS_3=total(PWCMPWGT3) if Sample3==1 & HRINTSTA3==1 & HRINTSTA4==2

*Share of 3 responder and 4 type A by LF status

gen Emp_TypeA_Rate_3=Emp_TypeA_3/Sample_TypeA_3
gen Umemp_TypeA_Rate_3=Unemp_TypeA_3/Sample_TypeA_3
gen NILF_TypeA_Rate_3=NILF_TypeA_3/Sample_TypeA_3
*same but with BLS weights
gen Emp_TypeA_BLS_Rate_3=Emp_TypeA_BLS_3/Sample_TypeA_BLS_3
gen Umemp_TypeA_BLS_Rate_3=Unemp_TypeA_BLS_3/Sample_TypeA_BLS_3
gen NILF_TypeA_BLS_Rate_3=NILF_TypeA_BLS_3/Sample_TypeA_BLS_3

****************************************************************************
*************** Repeat process for MIS 4 to 5

gen Emp4=1 if status4==1|status4==2
gen Unemp4=1 if status4==3|status4==4
gen NILF4=1 if status4==5|status4==6|status4==7
gen Sample4=1 if status4>0


*Find unemployment rates etc. for responders in MIS 4 and 5, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_4=total(Emp4) if HRINTSTA4==1 & HRINTSTA5==1
egen Unemp_Res_4=total(Unemp4) if HRINTSTA4==1 & HRINTSTA5==1
egen NILF_Res_4=total(NILF4) if HRINTSTA4==1 & HRINTSTA5==1
egen Sample_Res_4=total(Sample4) if HRINTSTA4==1 & HRINTSTA5==1
*do the same but with BLS weights
egen Emp_Res_BLS_4=total(PWCMPWGT4) if Emp4==1 & HRINTSTA4==1 & HRINTSTA5==1
egen Unemp_Res_BLS_4=total(PWCMPWGT4) if Unemp4==1 & HRINTSTA4==1 & HRINTSTA5==1
egen NILF_Res_BLS_4=total(PWCMPWGT4) if NILF4==1 & HRINTSTA4==1 & HRINTSTA5==1
egen Sample_Res_BLS_4=total(PWCMPWGT4) if Sample4==1 & HRINTSTA4==1 & HRINTSTA5==1

*Share of 4 and 5 responders by LF status

gen Emp_Res_Rate_4=Emp_Res_4/Sample_Res_4
gen Umemp_Res_Rate_4=Unemp_Res_4/Sample_Res_4
gen NILF_Res_Rate_4=NILF_Res_4/Sample_Res_4
*same but with BLS weights
gen Emp_Res_BLS_Rate_4=Emp_Res_BLS_4/Sample_Res_BLS_4
gen Umemp_Res_BLS_Rate_4=Unemp_Res_BLS_4/Sample_Res_BLS_4
gen NILF_Res_BLS_Rate_4=NILF_Res_BLS_4/Sample_Res_BLS_4

*Find unemployment rates etc. for responders in MIS 4 and TypeA 
*MIS 5, but define rates as share of sample, not traditional definition

egen Emp_TypeA_4=total(Emp4) if HRINTSTA4==1 & HRINTSTA5==2
egen Unemp_TypeA_4=total(Unemp4) if HRINTSTA4==1 & HRINTSTA5==2
egen NILF_TypeA_4=total(NILF4) if HRINTSTA4==1 & HRINTSTA5==2
egen Sample_TypeA_4=total(Sample4) if HRINTSTA4==1 & HRINTSTA5==2
*same but with BLS weights
egen Emp_TypeA_BLS_4=total(PWCMPWGT4) if Emp4==1 & HRINTSTA4==1 & HRINTSTA5==2
egen Unemp_TypeA_BLS_4=total(PWCMPWGT4) if Unemp4==1 & HRINTSTA4==1 & HRINTSTA5==2
egen NILF_TypeA_BLS_4=total(PWCMPWGT4) if NILF4==1 & HRINTSTA4==1 & HRINTSTA5==2
egen Sample_TypeA_BLS_4=total(PWCMPWGT4) if Sample4==1 & HRINTSTA4==1 & HRINTSTA5==2

*Share of 4 responder and 5 type A by LF status

gen Emp_TypeA_Rate_4=Emp_TypeA_4/Sample_TypeA_4
gen Umemp_TypeA_Rate_4=Unemp_TypeA_4/Sample_TypeA_4
gen NILF_TypeA_Rate_4=NILF_TypeA_4/Sample_TypeA_4
*same but with BLS weights
gen Emp_TypeA_BLS_Rate_4=Emp_TypeA_BLS_4/Sample_TypeA_BLS_4
gen Umemp_TypeA_BLS_Rate_4=Unemp_TypeA_BLS_4/Sample_TypeA_BLS_4
gen NILF_TypeA_BLS_Rate_4=NILF_TypeA_BLS_4/Sample_TypeA_BLS_4

****************************************************************************
*************** Repeat process for MIS 5 to 6

gen Emp5=1 if status5==1|status5==2
gen Unemp5=1 if status5==3|status5==4
gen NILF5=1 if status5==5|status5==6|status5==7
gen Sample5=1 if status5>0


*Find unemployment rates etc. for responders in MIS 5 and 6, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_5=total(Emp5) if HRINTSTA5==1 & HRINTSTA6==1
egen Unemp_Res_5=total(Unemp5) if HRINTSTA5==1 & HRINTSTA6==1
egen NILF_Res_5=total(NILF5) if HRINTSTA5==1 & HRINTSTA6==1
egen Sample_Res_5=total(Sample5) if HRINTSTA5==1 & HRINTSTA6==1
*do the same but with BLS weights
egen Emp_Res_BLS_5=total(PWCMPWGT5) if Emp5==1 & HRINTSTA5==1 & HRINTSTA6==1
egen Unemp_Res_BLS_5=total(PWCMPWGT5) if Unemp5==1 & HRINTSTA5==1 & HRINTSTA6==1
egen NILF_Res_BLS_5=total(PWCMPWGT5) if NILF5==1 & HRINTSTA5==1 & HRINTSTA6==1
egen Sample_Res_BLS_5=total(PWCMPWGT5) if Sample5==1 & HRINTSTA5==1 & HRINTSTA6==1

*Share of 5 and 6 responders by LF status

gen Emp_Res_Rate_5=Emp_Res_5/Sample_Res_5
gen Umemp_Res_Rate_5=Unemp_Res_5/Sample_Res_5
gen NILF_Res_Rate_5=NILF_Res_5/Sample_Res_5
*same but with BLS weights
gen Emp_Res_BLS_Rate_5=Emp_Res_BLS_5/Sample_Res_BLS_5
gen Umemp_Res_BLS_Rate_5=Unemp_Res_BLS_5/Sample_Res_BLS_5
gen NILF_Res_BLS_Rate_5=NILF_Res_BLS_5/Sample_Res_BLS_5

*Find unemployment rates etc. for responders in MIS 5 and TypeA 
*MIS 6, but define rates as share of sample, not traditional definition

egen Emp_TypeA_5=total(Emp5) if HRINTSTA5==1 & HRINTSTA6==2
egen Unemp_TypeA_5=total(Unemp5) if HRINTSTA5==1 & HRINTSTA6==2
egen NILF_TypeA_5=total(NILF5) if HRINTSTA5==1 & HRINTSTA6==2
egen Sample_TypeA_5=total(Sample5) if HRINTSTA5==1 & HRINTSTA6==2
*same but with BLS weights
egen Emp_TypeA_BLS_5=total(PWCMPWGT5) if Emp5==1 & HRINTSTA5==1 & HRINTSTA6==2
egen Unemp_TypeA_BLS_5=total(PWCMPWGT5) if Unemp5==1 & HRINTSTA5==1 & HRINTSTA6==2
egen NILF_TypeA_BLS_5=total(PWCMPWGT5) if NILF5==1 & HRINTSTA5==1 & HRINTSTA6==2
egen Sample_TypeA_BLS_5=total(PWCMPWGT5) if Sample5==1 & HRINTSTA5==1 & HRINTSTA6==2

*Share of 5 responder and 6 type A by LF status

gen Emp_TypeA_Rate_5=Emp_TypeA_5/Sample_TypeA_5
gen Umemp_TypeA_Rate_5=Unemp_TypeA_5/Sample_TypeA_5
gen NILF_TypeA_Rate_5=NILF_TypeA_5/Sample_TypeA_5
*same but with BLS weights
gen Emp_TypeA_BLS_Rate_5=Emp_TypeA_BLS_5/Sample_TypeA_BLS_5
gen Umemp_TypeA_BLS_Rate_5=Unemp_TypeA_BLS_5/Sample_TypeA_BLS_5
gen NILF_TypeA_BLS_Rate_5=NILF_TypeA_BLS_5/Sample_TypeA_BLS_5

****************************************************************************
*************** Repeat process for MIS 6 to 7

gen Emp6=1 if status6==1|status6==2
gen Unemp6=1 if status6==3|status6==4
gen NILF6=1 if status6==5|status6==6|status6==7
gen Sample6=1 if status6>0


*Find unemployment rates etc. for responders in MIS 6 and 7, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_6=total(Emp6) if HRINTSTA6==1 & HRINTSTA7==1
egen Unemp_Res_6=total(Unemp6) if HRINTSTA6==1 & HRINTSTA7==1
egen NILF_Res_6=total(NILF6) if HRINTSTA6==1 & HRINTSTA7==1
egen Sample_Res_6=total(Sample6) if HRINTSTA6==1 & HRINTSTA7==1
*do the same but with BLS weights
egen Emp_Res_BLS_6=total(PWCMPWGT6) if Emp6==1 & HRINTSTA6==1 & HRINTSTA7==1
egen Unemp_Res_BLS_6=total(PWCMPWGT6) if Unemp6==1 & HRINTSTA6==1 & HRINTSTA7==1
egen NILF_Res_BLS_6=total(PWCMPWGT6) if NILF6==1 & HRINTSTA6==1 & HRINTSTA7==1
egen Sample_Res_BLS_6=total(PWCMPWGT6) if Sample6==1 & HRINTSTA6==1 & HRINTSTA7==1

*Share of 6 and 7 responders by LF status

gen Emp_Res_Rate_6=Emp_Res_6/Sample_Res_6
gen Umemp_Res_Rate_6=Unemp_Res_6/Sample_Res_6
gen NILF_Res_Rate_6=NILF_Res_6/Sample_Res_6
*same but with BLS weights
gen Emp_Res_BLS_Rate_6=Emp_Res_BLS_6/Sample_Res_BLS_6
gen Umemp_Res_BLS_Rate_6=Unemp_Res_BLS_6/Sample_Res_BLS_6
gen NILF_Res_BLS_Rate_6=NILF_Res_BLS_6/Sample_Res_BLS_6

*Find unemployment rates etc. for responders in MIS 6 and TypeA 
*MIS 7, but define rates as share of sample, not traditional definition

egen Emp_TypeA_6=total(Emp6) if HRINTSTA6==1 & HRINTSTA7==2
egen Unemp_TypeA_6=total(Unemp6) if HRINTSTA6==1 & HRINTSTA7==2
egen NILF_TypeA_6=total(NILF6) if HRINTSTA6==1 & HRINTSTA7==2
egen Sample_TypeA_6=total(Sample6) if HRINTSTA6==1 & HRINTSTA7==2
*same but with BLS weights
egen Emp_TypeA_BLS_6=total(PWCMPWGT6) if Emp6==1 & HRINTSTA6==1 & HRINTSTA7==2
egen Unemp_TypeA_BLS_6=total(PWCMPWGT6) if Unemp6==1 & HRINTSTA6==1 & HRINTSTA7==2
egen NILF_TypeA_BLS_6=total(PWCMPWGT6) if NILF6==1 & HRINTSTA6==1 & HRINTSTA7==2
egen Sample_TypeA_BLS_6=total(PWCMPWGT6) if Sample6==1 & HRINTSTA6==1 & HRINTSTA7==2

*Share of 6 responder and 7 type A by LF status

gen Emp_TypeA_Rate_6=Emp_TypeA_6/Sample_TypeA_6
gen Umemp_TypeA_Rate_6=Unemp_TypeA_6/Sample_TypeA_6
gen NILF_TypeA_Rate_6=NILF_TypeA_6/Sample_TypeA_6
*same but with BLS weights
gen Emp_TypeA_BLS_Rate_6=Emp_TypeA_BLS_6/Sample_TypeA_BLS_6
gen Umemp_TypeA_BLS_Rate_6=Unemp_TypeA_BLS_6/Sample_TypeA_BLS_6
gen NILF_TypeA_BLS_Rate_6=NILF_TypeA_BLS_6/Sample_TypeA_BLS_6

****************************************************************************
*************** Repeat process for MIS 7 to 8

gen Emp7=1 if status7==1|status7==2
gen Unemp7=1 if status7==3|status7==4
gen NILF7=1 if status7==5|status7==6|status7==7
gen Sample7=1 if status7>0


*Find unemployment rates etc. for responders in MIS 7 and 8, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_7=total(Emp7) if HRINTSTA7==1 & HRINTSTA8==1
egen Unemp_Res_7=total(Unemp7) if HRINTSTA7==1 & HRINTSTA8==1
egen NILF_Res_7=total(NILF7) if HRINTSTA7==1 & HRINTSTA8==1
egen Sample_Res_7=total(Sample7) if HRINTSTA7==1 & HRINTSTA8==1
*do the same but with BLS weights
egen Emp_Res_BLS_7=total(PWCMPWGT7) if Emp7==1 & HRINTSTA7==1 & HRINTSTA8==1
egen Unemp_Res_BLS_7=total(PWCMPWGT7) if Unemp7==1 & HRINTSTA7==1 & HRINTSTA8==1
egen NILF_Res_BLS_7=total(PWCMPWGT7) if NILF7==1 & HRINTSTA7==1 & HRINTSTA8==1
egen Sample_Res_BLS_7=total(PWCMPWGT7) if Sample7==1 & HRINTSTA7==1 & HRINTSTA8==1

*Share of 7 and 8 responders by LF status

gen Emp_Res_Rate_7=Emp_Res_7/Sample_Res_7
gen Umemp_Res_Rate_7=Unemp_Res_7/Sample_Res_7
gen NILF_Res_Rate_7=NILF_Res_7/Sample_Res_7
*same but with BLS weights
gen Emp_Res_BLS_Rate_7=Emp_Res_BLS_7/Sample_Res_BLS_7
gen Umemp_Res_BLS_Rate_7=Unemp_Res_BLS_7/Sample_Res_BLS_7
gen NILF_Res_BLS_Rate_7=NILF_Res_BLS_7/Sample_Res_BLS_7

*Find unemployment rates etc. for responders in MIS 7 and TypeA 
*MIS 8, but define rates as share of sample, not traditional definition

egen Emp_TypeA_7=total(Emp7) if HRINTSTA7==1 & HRINTSTA8==2
egen Unemp_TypeA_7=total(Unemp7) if HRINTSTA7==1 & HRINTSTA8==2
egen NILF_TypeA_7=total(NILF7) if HRINTSTA7==1 & HRINTSTA8==2
egen Sample_TypeA_7=total(Sample7) if HRINTSTA7==1 & HRINTSTA8==2
*same but with BLS weights
egen Emp_TypeA_BLS_7=total(PWCMPWGT7) if Emp7==1 & HRINTSTA7==1 & HRINTSTA8==2
egen Unemp_TypeA_BLS_7=total(PWCMPWGT7) if Unemp7==1 & HRINTSTA7==1 & HRINTSTA8==2
egen NILF_TypeA_BLS_7=total(PWCMPWGT7) if NILF7==1 & HRINTSTA7==1 & HRINTSTA8==2
egen Sample_TypeA_BLS_7=total(PWCMPWGT7) if Sample7==1 & HRINTSTA7==1 & HRINTSTA8==2

*Share of 7 responder and 8 type A by LF status

gen Emp_TypeA_Rate_7=Emp_TypeA_7/Sample_TypeA_7
gen Umemp_TypeA_Rate_7=Unemp_TypeA_7/Sample_TypeA_7
gen NILF_TypeA_Rate_7=NILF_TypeA_7/Sample_TypeA_7
*same but with BLS weights
gen Emp_TypeA_BLS_Rate_7=Emp_TypeA_BLS_7/Sample_TypeA_BLS_7
gen Umemp_TypeA_BLS_Rate_7=Unemp_TypeA_BLS_7/Sample_TypeA_BLS_7
gen NILF_TypeA_BLS_Rate_7=NILF_TypeA_BLS_7/Sample_TypeA_BLS_7


*Average over all MIS:
 *leave out MIS 4 for drop-ins because that is 4 to 5, which is 8 month gap.

gen Emp_Res_tot=Emp_Res_1+Emp_Res_2+Emp_Res_3+Emp_Res_5+Emp_Res_6+Emp_Res_7
gen Unemp_Res_tot=Unemp_Res_1+Unemp_Res_2+Unemp_Res_3+Unemp_Res_5+Unemp_Res_6+Unemp_Res_7
gen NILF_Res_tot=NILF_Res_1+NILF_Res_2+NILF_Res_3+NILF_Res_5+NILF_Res_6+NILF_Res_7
gen Sample_Res_tot=Sample_Res_1+Sample_Res_2+Sample_Res_3+Sample_Res_5+Sample_Res_6+Sample_Res_7

*This generates the values in the response column in Panel A Table 1 (scroll down dataframe to where responders exist to see values)
gen Emp_Res_Rate_tot=Emp_Res_tot/Sample_Res_tot
gen Umemp_Res_Rate_tot=Unemp_Res_tot/Sample_Res_tot
gen NILF_Res_Rate_tot=NILF_Res_tot/Sample_Res_tot

*same for BLS weights
gen Emp_Res_BLS_tot=Emp_Res_BLS_1+Emp_Res_BLS_2+Emp_Res_BLS_3+Emp_Res_BLS_5+Emp_Res_BLS_6+Emp_Res_BLS_7
gen Unemp_Res_BLS_tot=Unemp_Res_BLS_1+Unemp_Res_BLS_2+Unemp_Res_BLS_3+Unemp_Res_BLS_5+Unemp_Res_BLS_6+Unemp_Res_BLS_7
gen NILF_Res_BLS_tot=NILF_Res_BLS_1+NILF_Res_BLS_2+NILF_Res_BLS_3+NILF_Res_BLS_5+NILF_Res_BLS_6+NILF_Res_BLS_7
gen Sample_Res_BLS_tot=Sample_Res_BLS_1+Sample_Res_BLS_2+Sample_Res_BLS_3+Sample_Res_BLS_5+Sample_Res_BLS_6+Sample_Res_BLS_7

gen Emp_Res_BLS_Rate_tot=Emp_Res_BLS_tot/Sample_Res_BLS_tot
gen Umemp_Res_BLS_Rate_tot=Unemp_Res_BLS_tot/Sample_Res_BLS_tot
gen NILF_Res_BLS_Rate_tot=NILF_Res_BLS_tot/Sample_Res_BLS_tot

*need to fill the type As because they don't overlap.
egen Emp_TypeA_1_fill=max(Emp_TypeA_1)
egen Emp_TypeA_2_fill=max(Emp_TypeA_2)
egen Emp_TypeA_3_fill=max(Emp_TypeA_3)
egen Emp_TypeA_4_fill=max(Emp_TypeA_4)
egen Emp_TypeA_5_fill=max(Emp_TypeA_5)
egen Emp_TypeA_6_fill=max(Emp_TypeA_6)
egen Emp_TypeA_7_fill=max(Emp_TypeA_7)

egen Unemp_TypeA_1_fill=max(Unemp_TypeA_1)
egen Unemp_TypeA_2_fill=max(Unemp_TypeA_2)
egen Unemp_TypeA_3_fill=max(Unemp_TypeA_3)
egen Unemp_TypeA_4_fill=max(Unemp_TypeA_4)
egen Unemp_TypeA_5_fill=max(Unemp_TypeA_5)
egen Unemp_TypeA_6_fill=max(Unemp_TypeA_6)
egen Unemp_TypeA_7_fill=max(Unemp_TypeA_7)

egen NILF_TypeA_1_fill=max(NILF_TypeA_1)
egen NILF_TypeA_2_fill=max(NILF_TypeA_2)
egen NILF_TypeA_3_fill=max(NILF_TypeA_3)
egen NILF_TypeA_4_fill=max(NILF_TypeA_4)
egen NILF_TypeA_5_fill=max(NILF_TypeA_5)
egen NILF_TypeA_6_fill=max(NILF_TypeA_6)
egen NILF_TypeA_7_fill=max(NILF_TypeA_7)

egen Sample_TypeA_1_fill=max(Sample_TypeA_1)
egen Sample_TypeA_2_fill=max(Sample_TypeA_2)
egen Sample_TypeA_3_fill=max(Sample_TypeA_3)
egen Sample_TypeA_4_fill=max(Sample_TypeA_4)
egen Sample_TypeA_5_fill=max(Sample_TypeA_5)
egen Sample_TypeA_6_fill=max(Sample_TypeA_6)
egen Sample_TypeA_7_fill=max(Sample_TypeA_7)

gen Emp_TypeA_tot=Emp_TypeA_1_fill+Emp_TypeA_2_fill+Emp_TypeA_3_fill+Emp_TypeA_5_fill+Emp_TypeA_6_fill+Emp_TypeA_7_fill
gen Unemp_TypeA_tot=Unemp_TypeA_1_fill+Unemp_TypeA_2_fill+Unemp_TypeA_3_fill+Unemp_TypeA_5_fill+Unemp_TypeA_6_fill+Unemp_TypeA_7_fill
gen NILF_TypeA_tot=NILF_TypeA_1_fill+NILF_TypeA_2_fill+NILF_TypeA_3_fill+NILF_TypeA_5_fill+NILF_TypeA_6_fill+NILF_TypeA_7_fill
gen Sample_TypeA_tot=Sample_TypeA_1_fill+Sample_TypeA_2_fill+Sample_TypeA_3_fill+Sample_TypeA_5_fill+Sample_TypeA_6_fill+Sample_TypeA_7_fill


*This generates the values in the nonresponse column in Panel A Table 1
gen Emp_TypeA_Rate_tot=Emp_TypeA_tot/Sample_TypeA_tot
gen Umemp_TypeA_Rate_tot=Unemp_TypeA_tot/Sample_TypeA_tot
gen NILF_TypeA_Rate_tot=NILF_TypeA_tot/Sample_TypeA_tot

*same for BLS weights
egen Emp_TypeA_BLS_1_fill=max(Emp_TypeA_BLS_1)
egen Emp_TypeA_BLS_2_fill=max(Emp_TypeA_BLS_2)
egen Emp_TypeA_BLS_3_fill=max(Emp_TypeA_BLS_3)
egen Emp_TypeA_BLS_4_fill=max(Emp_TypeA_BLS_4)
egen Emp_TypeA_BLS_5_fill=max(Emp_TypeA_BLS_5)
egen Emp_TypeA_BLS_6_fill=max(Emp_TypeA_BLS_6)
egen Emp_TypeA_BLS_7_fill=max(Emp_TypeA_BLS_7)

egen Unemp_TypeA_BLS_1_fill=max(Unemp_TypeA_BLS_1)
egen Unemp_TypeA_BLS_2_fill=max(Unemp_TypeA_BLS_2)
egen Unemp_TypeA_BLS_3_fill=max(Unemp_TypeA_BLS_3)
egen Unemp_TypeA_BLS_4_fill=max(Unemp_TypeA_BLS_4)
egen Unemp_TypeA_BLS_5_fill=max(Unemp_TypeA_BLS_5)
egen Unemp_TypeA_BLS_6_fill=max(Unemp_TypeA_BLS_6)
egen Unemp_TypeA_BLS_7_fill=max(Unemp_TypeA_BLS_7)

egen NILF_TypeA_BLS_1_fill=max(NILF_TypeA_BLS_1)
egen NILF_TypeA_BLS_2_fill=max(NILF_TypeA_BLS_2)
egen NILF_TypeA_BLS_3_fill=max(NILF_TypeA_BLS_3)
egen NILF_TypeA_BLS_4_fill=max(NILF_TypeA_BLS_4)
egen NILF_TypeA_BLS_5_fill=max(NILF_TypeA_BLS_5)
egen NILF_TypeA_BLS_6_fill=max(NILF_TypeA_BLS_6)
egen NILF_TypeA_BLS_7_fill=max(NILF_TypeA_BLS_7)

egen Sample_TypeA_BLS_1_fill=max(Sample_TypeA_BLS_1)
egen Sample_TypeA_BLS_2_fill=max(Sample_TypeA_BLS_2)
egen Sample_TypeA_BLS_3_fill=max(Sample_TypeA_BLS_3)
egen Sample_TypeA_BLS_4_fill=max(Sample_TypeA_BLS_4)
egen Sample_TypeA_BLS_5_fill=max(Sample_TypeA_BLS_5)
egen Sample_TypeA_BLS_6_fill=max(Sample_TypeA_BLS_6)
egen Sample_TypeA_BLS_7_fill=max(Sample_TypeA_BLS_7)

gen Emp_TypeA_BLS_tot=Emp_TypeA_BLS_1_fill+Emp_TypeA_BLS_2_fill+Emp_TypeA_BLS_3_fill+Emp_TypeA_BLS_5_fill+Emp_TypeA_BLS_6_fill+Emp_TypeA_BLS_7_fill
gen Unemp_TypeA_BLS_tot=Unemp_TypeA_BLS_1_fill+Unemp_TypeA_BLS_2_fill+Unemp_TypeA_BLS_3_fill+Unemp_TypeA_BLS_5_fill+Unemp_TypeA_BLS_6_fill+Unemp_TypeA_BLS_7_fill
gen NILF_TypeA_BLS_tot=NILF_TypeA_BLS_1_fill+NILF_TypeA_BLS_2_fill+NILF_TypeA_BLS_3_fill+NILF_TypeA_BLS_5_fill+NILF_TypeA_BLS_6_fill+NILF_TypeA_BLS_7_fill
gen Sample_TypeA_BLS_tot=Sample_TypeA_BLS_1_fill+Sample_TypeA_BLS_2_fill+Sample_TypeA_BLS_3_fill+Sample_TypeA_BLS_5_fill+Sample_TypeA_BLS_6_fill+Sample_TypeA_BLS_7_fill

gen Emp_TypeA_BLS_Rate_tot=Emp_TypeA_BLS_tot/Sample_TypeA_BLS_tot
gen Umemp_TypeA_BLS_Rate_tot=Unemp_TypeA_BLS_tot/Sample_TypeA_BLS_tot
gen NILF_TypeA_BLS_Rate_tot=NILF_TypeA_BLS_tot/Sample_TypeA_BLS_tot



**==========================================================
**===========================================================
*do same thing put for drop ins.

gen Emp1_dropin=1 if status2==1|status2==2
gen Unemp1_dropin=1 if status2==3|status2==4
gen NILF1_dropin=1 if status2==5|status2==6|status2==7
gen Sample1_dropin=1 if status2>0


*Find unemployment rates etc. for responders in MIS 1 and 2, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_1_dropin=total(Emp1_dropin) if HRINTSTA1==1 & HRINTSTA2==1
egen Unemp_Res_1_dropin=total(Unemp1_dropin) if HRINTSTA1==1 & HRINTSTA2==1
egen NILF_Res_1_dropin=total(NILF1_dropin) if HRINTSTA1==1 & HRINTSTA2==1
egen Sample_Res_1_dropin=total(Sample1_dropin) if HRINTSTA1==1 & HRINTSTA2==1

*do the same but with BLS weights
egen Emp_Res_BLS_1_dropin=total(PWCMPWGT2) if Emp1_dropin==1 & HRINTSTA1==1 & HRINTSTA2==1
egen Unemp_Res_BLS_1_dropin=total(PWCMPWGT2) if Unemp1_dropin==1 & HRINTSTA1==1 & HRINTSTA2==1
egen NILF_Res_BLS_1_dropin=total(PWCMPWGT2) if NILF1_dropin==1 & HRINTSTA1==1 & HRINTSTA2==1
egen Sample_Res_BLS_1_dropin=total(PWCMPWGT2) if Sample1_dropin==1 & HRINTSTA1==1 & HRINTSTA2==1

*Share of 1 and 2 responders by LF status

gen Emp_Res_Rate_1_dropin=Emp_Res_1_dropin/Sample_Res_1_dropin
gen Umemp_Res_Rate_1_dropin=Unemp_Res_1_dropin/Sample_Res_1_dropin
gen NILF_Res_Rate_1_dropin=NILF_Res_1_dropin/Sample_Res_1_dropin
*same but with BLS weights
gen Emp_Res_BLS_Rate_1_dropin=Emp_Res_BLS_1_dropin/Sample_Res_BLS_1_dropin
gen Umemp_Res_BLS_Rate_1_dropin=Unemp_Res_BLS_1_dropin/Sample_Res_BLS_1_dropin
gen NILF_Res_BLS_Rate_1_dropin=NILF_Res_BLS_1_dropin/Sample_Res_BLS_1_dropin

*Find unemployment rates etc. for typeA in MIS 1 and responder 
*MIS 2, but define rates as share of sample, not traditional definition

egen Emp_TypeA_1_dropin=total(Emp1_dropin) if HRINTSTA1==2 & HRINTSTA2==1
egen Unemp_TypeA_1_dropin=total(Unemp1_dropin) if HRINTSTA1==2 & HRINTSTA2==1
egen NILF_TypeA_1_dropin=total(NILF1_dropin) if HRINTSTA1==2 & HRINTSTA2==1
egen Sample_TypeA_1_dropin=total(Sample1_dropin) if HRINTSTA1==2 & HRINTSTA2==1
*same but with BLS weights
egen Emp_TypeA_BLS_1_dropin=total(PWCMPWGT2) if Emp1_dropin==1 & HRINTSTA1==2 & HRINTSTA2==1
egen Unemp_TypeA_BLS_1_dropin=total(PWCMPWGT2) if Unemp1_dropin==1 & HRINTSTA1==2 & HRINTSTA2==1
egen NILF_TypeA_BLS_1_dropin=total(PWCMPWGT2) if NILF1_dropin==1 & HRINTSTA1==2 & HRINTSTA2==1
egen Sample_TypeA_BLS_1_dropin=total(PWCMPWGT2) if Sample1_dropin==1 & HRINTSTA1==2 & HRINTSTA2==1

*Share of 1 type A and 2 responder by LF status

gen Emp_TypeA_Rate_1_dropin=Emp_TypeA_1_dropin/Sample_TypeA_1_dropin
gen Umemp_TypeA_Rate_1_dropin=Unemp_TypeA_1_dropin/Sample_TypeA_1_dropin
gen NILF_TypeA_Rate_1_dropin=NILF_TypeA_1_dropin/Sample_TypeA_1_dropin
*same but with BLS weights
gen Emp_TypeA_BLS_Rate_1_dropin=Emp_TypeA_BLS_1_dropin/Sample_TypeA_BLS_1_dropin
gen Umemp_TypeA_BLS_Rate_1_dropin=Unemp_TypeA_BLS_1_dropin/Sample_TypeA_BLS_1_dropin
gen NILF_TypeA_BLS_Rate_1_dropin=NILF_TypeA_BLS_1_dropin/Sample_TypeA_BLS_1_dropin

****************************************************************************
*************** Repeat process for MIS 2 to 3


gen Emp2_dropin=1 if status3==1|status3==2
gen Unemp2_dropin=1 if status3==3|status3==4
gen NILF2_dropin=1 if status3==5|status3==6|status3==7
gen Sample2_dropin=1 if status3>0


*Find unemployment rates etc. for responders in MIS 2 and 3, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_2_dropin=total(Emp2_dropin) if HRINTSTA2==1 & HRINTSTA3==1
egen Unemp_Res_2_dropin=total(Unemp2_dropin) if HRINTSTA2==1 & HRINTSTA3==1
egen NILF_Res_2_dropin=total(NILF2_dropin) if HRINTSTA2==1 & HRINTSTA3==1
egen Sample_Res_2_dropin=total(Sample2_dropin) if HRINTSTA2==1 & HRINTSTA3==1
*do the same but with BLS weights
egen Emp_Res_BLS_2_dropin=total(PWCMPWGT3) if Emp2_dropin==1 & HRINTSTA2==1 & HRINTSTA3==1
egen Unemp_Res_BLS_2_dropin=total(PWCMPWGT3) if Unemp2_dropin==1 & HRINTSTA2==1 & HRINTSTA3==1
egen NILF_Res_BLS_2_dropin=total(PWCMPWGT3) if NILF2_dropin==1 & HRINTSTA2==1 & HRINTSTA3==1
egen Sample_Res_BLS_2_dropin=total(PWCMPWGT3) if Sample2_dropin==1 & HRINTSTA2==1 & HRINTSTA3==1

*Share of 2 and 3 responders by LF status

gen Emp_Res_Rate_2_dropin=Emp_Res_2_dropin/Sample_Res_2_dropin
gen Umemp_Res_Rate_2_dropin=Unemp_Res_2_dropin/Sample_Res_2_dropin
gen NILF_Res_Rate_2_dropin=NILF_Res_2_dropin/Sample_Res_2_dropin

*Find unemployment rates etc. for typeA in MIS 2 and responder 
*MIS 3, but define rates as share of sample, not traditional definition

egen Emp_TypeA_2_dropin=total(Emp2_dropin) if HRINTSTA2==2 & HRINTSTA3==1
egen Unemp_TypeA_2_dropin=total(Unemp2_dropin) if HRINTSTA2==2 & HRINTSTA3==1
egen NILF_TypeA_2_dropin=total(NILF2_dropin) if HRINTSTA2==2 & HRINTSTA3==1
egen Sample_TypeA_2_dropin=total(Sample2_dropin) if HRINTSTA2==2 & HRINTSTA3==1
*same but with BLS weights
egen Emp_TypeA_BLS_2_dropin=total(PWCMPWGT3) if Emp2_dropin==1 & HRINTSTA2==2 & HRINTSTA3==1
egen Unemp_TypeA_BLS_2_dropin=total(PWCMPWGT3) if Unemp2_dropin==1 & HRINTSTA2==2 & HRINTSTA3==1
egen NILF_TypeA_BLS_2_dropin=total(PWCMPWGT3) if NILF2_dropin==1 & HRINTSTA2==2 & HRINTSTA3==1
egen Sample_TypeA_BLS_2_dropin=total(PWCMPWGT3) if Sample2_dropin==1 & HRINTSTA2==2 & HRINTSTA3==1

*Share of 2 type A and 3 responder by LF status

gen Emp_TypeA_Rate_2_dropin=Emp_TypeA_2_dropin/Sample_TypeA_2_dropin
gen Umemp_TypeA_Rate_2_dropin=Unemp_TypeA_2_dropin/Sample_TypeA_2_dropin
gen NILF_TypeA_Rate_2_dropin=NILF_TypeA_2_dropin/Sample_TypeA_2_dropin


****************************************************************************
*************** Repeat process for MIS 3 to 4


gen Emp3_dropin=1 if status4==1|status4==2
gen Unemp3_dropin=1 if status4==3|status4==4
gen NILF3_dropin=1 if status4==5|status4==6|status4==7
gen Sample3_dropin=1 if status4>0


*Find unemployment rates etc. for responders in MIS 3 and 4, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_3_dropin=total(Emp3_dropin) if HRINTSTA3==1 & HRINTSTA4==1
egen Unemp_Res_3_dropin=total(Unemp3_dropin) if HRINTSTA3==1 & HRINTSTA4==1
egen NILF_Res_3_dropin=total(NILF3_dropin) if HRINTSTA3==1 & HRINTSTA4==1
egen Sample_Res_3_dropin=total(Sample3_dropin) if HRINTSTA3==1 & HRINTSTA4==1
*do the same but with BLS weights
egen Emp_Res_BLS_3_dropin=total(PWCMPWGT4) if Emp3_dropin==1 & HRINTSTA3==1 & HRINTSTA4==1
egen Unemp_Res_BLS_3_dropin=total(PWCMPWGT4) if Unemp3_dropin==1 & HRINTSTA3==1 & HRINTSTA4==1
egen NILF_Res_BLS_3_dropin=total(PWCMPWGT4) if NILF3_dropin==1 & HRINTSTA3==1 & HRINTSTA4==1
egen Sample_Res_BLS_3_dropin=total(PWCMPWGT4) if Sample3_dropin==1 & HRINTSTA3==1 & HRINTSTA4==1

*Share of 3 and 4 responders by LF status

gen Emp_Res_Rate_3_dropin=Emp_Res_3_dropin/Sample_Res_3_dropin
gen Umemp_Res_Rate_3_dropin=Unemp_Res_3_dropin/Sample_Res_3_dropin
gen NILF_Res_Rate_3_dropin=NILF_Res_3_dropin/Sample_Res_3_dropin

*Find unemployment rates etc. for typeA in MIS 3 and responder 
*MIS 4, but define rates as share of sample, not traditional definition

egen Emp_TypeA_3_dropin=total(Emp3_dropin) if HRINTSTA3==2 & HRINTSTA4==1
egen Unemp_TypeA_3_dropin=total(Unemp3_dropin) if HRINTSTA3==2 & HRINTSTA4==1
egen NILF_TypeA_3_dropin=total(NILF3_dropin) if HRINTSTA3==2 & HRINTSTA4==1
egen Sample_TypeA_3_dropin=total(Sample3_dropin) if HRINTSTA3==2 & HRINTSTA4==1
*same but with BLS weights
egen Emp_TypeA_BLS_3_dropin=total(PWCMPWGT4) if Emp3_dropin==1 & HRINTSTA3==2 & HRINTSTA4==1
egen Unemp_TypeA_BLS_3_dropin=total(PWCMPWGT4) if Unemp3_dropin==1 & HRINTSTA3==2 & HRINTSTA4==1
egen NILF_TypeA_BLS_3_dropin=total(PWCMPWGT4) if NILF3_dropin==1 & HRINTSTA3==2 & HRINTSTA4==1
egen Sample_TypeA_BLS_3_dropin=total(PWCMPWGT4) if Sample3_dropin==1 & HRINTSTA3==2 & HRINTSTA4==1

*Share of 3 type A and 4 responder by LF status

gen Emp_TypeA_Rate_3_dropin=Emp_TypeA_3_dropin/Sample_TypeA_3_dropin
gen Umemp_TypeA_Rate_3_dropin=Unemp_TypeA_3_dropin/Sample_TypeA_3_dropin
gen NILF_TypeA_Rate_3_dropin=NILF_TypeA_3_dropin/Sample_TypeA_3_dropin

****************************************************************************
*************** Repeat process for MIS 4 to 5


gen Emp4_dropin=1 if status5==1|status5==2
gen Unemp4_dropin=1 if status5==3|status5==4
gen NILF4_dropin=1 if status5==5|status5==6|status5==7
gen Sample4_dropin=1 if status5>0


*Find unemployment rates etc. for responders in MIS 4 and 5, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_4_dropin=total(Emp4_dropin) if HRINTSTA4==1 & HRINTSTA5==1
egen Unemp_Res_4_dropin=total(Unemp4_dropin) if HRINTSTA4==1 & HRINTSTA5==1
egen NILF_Res_4_dropin=total(NILF4_dropin) if HRINTSTA4==1 & HRINTSTA5==1
egen Sample_Res_4_dropin=total(Sample4_dropin) if HRINTSTA4==1 & HRINTSTA5==1
*do the same but with BLS weights
egen Emp_Res_BLS_4_dropin=total(PWCMPWGT5) if Emp4_dropin==1 & HRINTSTA4==1 & HRINTSTA5==1
egen Unemp_Res_BLS_4_dropin=total(PWCMPWGT5) if Unemp4_dropin==1 & HRINTSTA4==1 & HRINTSTA5==1
egen NILF_Res_BLS_4_dropin=total(PWCMPWGT5) if NILF4_dropin==1 & HRINTSTA4==1 & HRINTSTA5==1
egen Sample_Res_BLS_4_dropin=total(PWCMPWGT5) if Sample4_dropin==1 & HRINTSTA4==1 & HRINTSTA5==1

*Share of 4 and 5 responders by LF status

gen Emp_Res_Rate_4_dropin=Emp_Res_4_dropin/Sample_Res_4_dropin
gen Umemp_Res_Rate_4_dropin=Unemp_Res_4_dropin/Sample_Res_4_dropin
gen NILF_Res_Rate_4_dropin=NILF_Res_4_dropin/Sample_Res_4_dropin

*Find unemployment rates etc. for typeA in MIS 4 and responder 
*MIS 5, but define rates as share of sample, not traditional definition

egen Emp_TypeA_4_dropin=total(Emp4_dropin) if HRINTSTA4==2 & HRINTSTA5==1
egen Unemp_TypeA_4_dropin=total(Unemp4_dropin) if HRINTSTA4==2 & HRINTSTA5==1
egen NILF_TypeA_4_dropin=total(NILF4_dropin) if HRINTSTA4==2 & HRINTSTA5==1
egen Sample_TypeA_4_dropin=total(Sample4_dropin) if HRINTSTA4==2 & HRINTSTA5==1
*same but with BLS weights
egen Emp_TypeA_BLS_4_dropin=total(PWCMPWGT5) if Emp4_dropin==1 & HRINTSTA4==2 & HRINTSTA5==1
egen Unemp_TypeA_BLS_4_dropin=total(PWCMPWGT5) if Unemp4_dropin==1 & HRINTSTA4==2 & HRINTSTA5==1
egen NILF_TypeA_BLS_4_dropin=total(PWCMPWGT5) if NILF4_dropin==1 & HRINTSTA4==2 & HRINTSTA5==1
egen Sample_TypeA_BLS_4_dropin=total(PWCMPWGT5) if Sample4_dropin==1 & HRINTSTA4==2 & HRINTSTA5==1

*Share of 4 type A and 5 responder by LF status

gen Emp_TypeA_Rate_4_dropin=Emp_TypeA_4_dropin/Sample_TypeA_4_dropin
gen Umemp_TypeA_Rate_4_dropin=Unemp_TypeA_4_dropin/Sample_TypeA_4_dropin
gen NILF_TypeA_Rate_4_dropin=NILF_TypeA_4_dropin/Sample_TypeA_4_dropin

****************************************************************************
*************** Repeat process for MIS 5 to 6


gen Emp5_dropin=1 if status6==1|status6==2
gen Unemp5_dropin=1 if status6==3|status6==4
gen NILF5_dropin=1 if status6==5|status6==6|status6==7
gen Sample5_dropin=1 if status6>0


*Find unemployment rates etc. for responders in MIS 5 and 6, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_5_dropin=total(Emp5_dropin) if HRINTSTA5==1 & HRINTSTA6==1
egen Unemp_Res_5_dropin=total(Unemp5_dropin) if HRINTSTA5==1 & HRINTSTA6==1
egen NILF_Res_5_dropin=total(NILF5_dropin) if HRINTSTA5==1 & HRINTSTA6==1
egen Sample_Res_5_dropin=total(Sample5_dropin) if HRINTSTA5==1 & HRINTSTA6==1
*do the same but with BLS weights
egen Emp_Res_BLS_5_dropin=total(PWCMPWGT6) if Emp5_dropin==1 & HRINTSTA5==1 & HRINTSTA6==1
egen Unemp_Res_BLS_5_dropin=total(PWCMPWGT6) if Unemp5_dropin==1 & HRINTSTA5==1 & HRINTSTA6==1
egen NILF_Res_BLS_5_dropin=total(PWCMPWGT6) if NILF5_dropin==1 & HRINTSTA5==1 & HRINTSTA6==1
egen Sample_Res_BLS_5_dropin=total(PWCMPWGT6) if Sample5_dropin==1 & HRINTSTA5==1 & HRINTSTA6==1

*Share of 5 and 6 responders by LF status

gen Emp_Res_Rate_5_dropin=Emp_Res_5_dropin/Sample_Res_5_dropin
gen Umemp_Res_Rate_5_dropin=Unemp_Res_5_dropin/Sample_Res_5_dropin
gen NILF_Res_Rate_5_dropin=NILF_Res_5_dropin/Sample_Res_5_dropin

*Find unemployment rates etc. for typeA in MIS 5 and responder 
*MIS 6, but define rates as share of sample, not traditional definition

egen Emp_TypeA_5_dropin=total(Emp5_dropin) if HRINTSTA5==2 & HRINTSTA6==1
egen Unemp_TypeA_5_dropin=total(Unemp5_dropin) if HRINTSTA5==2 & HRINTSTA6==1
egen NILF_TypeA_5_dropin=total(NILF5_dropin) if HRINTSTA5==2 & HRINTSTA6==1
egen Sample_TypeA_5_dropin=total(Sample5_dropin) if HRINTSTA5==2 & HRINTSTA6==1
*same but with BLS weights
egen Emp_TypeA_BLS_5_dropin=total(PWCMPWGT6) if Emp5_dropin==1 & HRINTSTA5==2 & HRINTSTA6==1
egen Unemp_TypeA_BLS_5_dropin=total(PWCMPWGT6) if Unemp5_dropin==1 & HRINTSTA5==2 & HRINTSTA6==1
egen NILF_TypeA_BLS_5_dropin=total(PWCMPWGT6) if NILF5_dropin==1 & HRINTSTA5==2 & HRINTSTA6==1
egen Sample_TypeA_BLS_5_dropin=total(PWCMPWGT6) if Sample5_dropin==1 & HRINTSTA5==2 & HRINTSTA6==1

*Share of 5 type A and 6 responder by LF status

gen Emp_TypeA_Rate_5_dropin=Emp_TypeA_5_dropin/Sample_TypeA_5_dropin
gen Umemp_TypeA_Rate_5_dropin=Unemp_TypeA_5_dropin/Sample_TypeA_5_dropin
gen NILF_TypeA_Rate_5_dropin=NILF_TypeA_5_dropin/Sample_TypeA_5_dropin


****************************************************************************
*************** Repeat process for MIS 6 to 7


gen Emp6_dropin=1 if status7==1|status7==2
gen Unemp6_dropin=1 if status7==3|status7==4
gen NILF6_dropin=1 if status7==5|status7==6|status7==7
gen Sample6_dropin=1 if status7>0


*Find unemployment rates etc. for responders in MIS 6 and 7, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_6_dropin=total(Emp6_dropin) if HRINTSTA6==1 & HRINTSTA7==1
egen Unemp_Res_6_dropin=total(Unemp6_dropin) if HRINTSTA6==1 & HRINTSTA7==1
egen NILF_Res_6_dropin=total(NILF6_dropin) if HRINTSTA6==1 & HRINTSTA7==1
egen Sample_Res_6_dropin=total(Sample6_dropin) if HRINTSTA6==1 & HRINTSTA7==1
*do the same but with BLS weights
egen Emp_Res_BLS_6_dropin=total(PWCMPWGT7) if Emp6_dropin==1 & HRINTSTA6==1 & HRINTSTA7==1
egen Unemp_Res_BLS_6_dropin=total(PWCMPWGT7) if Unemp6_dropin==1 & HRINTSTA6==1 & HRINTSTA7==1
egen NILF_Res_BLS_6_dropin=total(PWCMPWGT7) if NILF6_dropin==1 & HRINTSTA6==1 & HRINTSTA7==1
egen Sample_Res_BLS_6_dropin=total(PWCMPWGT7) if Sample6_dropin==1 & HRINTSTA6==1 & HRINTSTA7==1

*Share of 6 and 7 responders by LF status

gen Emp_Res_Rate_6_dropin=Emp_Res_6_dropin/Sample_Res_6_dropin
gen Umemp_Res_Rate_6_dropin=Unemp_Res_6_dropin/Sample_Res_6_dropin
gen NILF_Res_Rate_6_dropin=NILF_Res_6_dropin/Sample_Res_6_dropin

*Find unemployment rates etc. for typeA in MIS 6 and responder 
*MIS 7, but define rates as share of sample, not traditional definition

egen Emp_TypeA_6_dropin=total(Emp6_dropin) if HRINTSTA6==2 & HRINTSTA7==1
egen Unemp_TypeA_6_dropin=total(Unemp6_dropin) if HRINTSTA6==2 & HRINTSTA7==1
egen NILF_TypeA_6_dropin=total(NILF6_dropin) if HRINTSTA6==2 & HRINTSTA7==1
egen Sample_TypeA_6_dropin=total(Sample6_dropin) if HRINTSTA6==2 & HRINTSTA7==1
*same but with BLS weights
egen Emp_TypeA_BLS_6_dropin=total(PWCMPWGT7) if Emp6_dropin==1 & HRINTSTA6==2 & HRINTSTA7==1
egen Unemp_TypeA_BLS_6_dropin=total(PWCMPWGT7) if Unemp6_dropin==1 & HRINTSTA6==2 & HRINTSTA7==1
egen NILF_TypeA_BLS_6_dropin=total(PWCMPWGT7) if NILF6_dropin==1 & HRINTSTA6==2 & HRINTSTA7==1
egen Sample_TypeA_BLS_6_dropin=total(PWCMPWGT7) if Sample6_dropin==1 & HRINTSTA6==2 & HRINTSTA7==1

*Share of 6 type A and 7 responder by LF status

gen Emp_TypeA_Rate_6_dropin=Emp_TypeA_6_dropin/Sample_TypeA_6_dropin
gen Umemp_TypeA_Rate_6_dropin=Unemp_TypeA_6_dropin/Sample_TypeA_6_dropin
gen NILF_TypeA_Rate_6_dropin=NILF_TypeA_6_dropin/Sample_TypeA_6_dropin

****************************************************************************
*************** Repeat process for MIS 7 to 8


gen Emp7_dropin=1 if status8==1|status8==2
gen Unemp7_dropin=1 if status8==3|status8==4
gen NILF7_dropin=1 if status8==5|status8==6|status8==7
gen Sample7_dropin=1 if status8>0


*Find unemployment rates etc. for responders in MIS 7 and 8, but define rates 
*as share of sample, not traditional definition

egen Emp_Res_7_dropin=total(Emp7_dropin) if HRINTSTA7==1 & HRINTSTA8==1
egen Unemp_Res_7_dropin=total(Unemp7_dropin) if HRINTSTA7==1 & HRINTSTA8==1
egen NILF_Res_7_dropin=total(NILF7_dropin) if HRINTSTA7==1 & HRINTSTA8==1
egen Sample_Res_7_dropin=total(Sample7_dropin) if HRINTSTA7==1 & HRINTSTA8==1
*do the same but with BLS weights
egen Emp_Res_BLS_7_dropin=total(PWCMPWGT8) if Emp7_dropin==1 & HRINTSTA7==1 & HRINTSTA8==1
egen Unemp_Res_BLS_7_dropin=total(PWCMPWGT8) if Unemp7_dropin==1 & HRINTSTA7==1 & HRINTSTA8==1
egen NILF_Res_BLS_7_dropin=total(PWCMPWGT8) if NILF7_dropin==1 & HRINTSTA7==1 & HRINTSTA8==1
egen Sample_Res_BLS_7_dropin=total(PWCMPWGT8) if Sample7_dropin==1 & HRINTSTA7==1 & HRINTSTA8==1

*Share of 7 and 8 responders by LF status

gen Emp_Res_Rate_7_dropin=Emp_Res_7_dropin/Sample_Res_7_dropin
gen Umemp_Res_Rate_7_dropin=Unemp_Res_7_dropin/Sample_Res_7_dropin
gen NILF_Res_Rate_7_dropin=NILF_Res_7_dropin/Sample_Res_7_dropin

*Find unemployment rates etc. for typeA in MIS 7 and responder 
*MIS 8, but define rates as share of sample, not traditional definition

egen Emp_TypeA_7_dropin=total(Emp7_dropin) if HRINTSTA7==2 & HRINTSTA8==1
egen Unemp_TypeA_7_dropin=total(Unemp7_dropin) if HRINTSTA7==2 & HRINTSTA8==1
egen NILF_TypeA_7_dropin=total(NILF7_dropin) if HRINTSTA7==2 & HRINTSTA8==1
egen Sample_TypeA_7_dropin=total(Sample7_dropin) if HRINTSTA7==2 & HRINTSTA8==1
*same but with BLS weights
egen Emp_TypeA_BLS_7_dropin=total(PWCMPWGT8) if Emp7_dropin==1 & HRINTSTA7==2 & HRINTSTA8==1
egen Unemp_TypeA_BLS_7_dropin=total(PWCMPWGT8) if Unemp7_dropin==1 & HRINTSTA7==2 & HRINTSTA8==1
egen NILF_TypeA_BLS_7_dropin=total(PWCMPWGT8) if NILF7_dropin==1 & HRINTSTA7==2 & HRINTSTA8==1
egen Sample_TypeA_BLS_7_dropin=total(PWCMPWGT8) if Sample7_dropin==1 & HRINTSTA7==2 & HRINTSTA8==1


*Share of 7 type A and 8 responder by LF status

gen Emp_TypeA_Rate_7_dropin=Emp_TypeA_7_dropin/Sample_TypeA_7_dropin
gen Umemp_TypeA_Rate_7_dropin=Unemp_TypeA_7_dropin/Sample_TypeA_7_dropin
gen NILF_TypeA_Rate_7_dropin=NILF_TypeA_7_dropin/Sample_TypeA_7_dropin


*Average over all MIS:
*leave out MIS label 4 because that is looking across the 8-month survey gap

gen Emp_Res_dropin_tot=Emp_Res_1_dropin+Emp_Res_2_dropin+Emp_Res_3_dropin+Emp_Res_5_dropin+Emp_Res_6_dropin+Emp_Res_7_dropin
gen Unemp_Res_dropin_tot=Unemp_Res_1_dropin+Unemp_Res_2_dropin+Unemp_Res_3_dropin+Unemp_Res_5_dropin+Unemp_Res_6_dropin+Unemp_Res_7_dropin
gen NILF_Res_dropin_tot=NILF_Res_1_dropin+NILF_Res_2_dropin+NILF_Res_3_dropin+NILF_Res_5_dropin+NILF_Res_6_dropin+NILF_Res_7_dropin
gen Sample_Res_dropin_tot=Sample_Res_1_dropin+Sample_Res_2_dropin+Sample_Res_3_dropin+Sample_Res_5_dropin+Sample_Res_6_dropin+Sample_Res_7_dropin


*This generates the values in the response column in Panel B Table 1 (scroll down dataframe to where responders exist to see values)
gen Emp_Res_Rate_dropin_tot=Emp_Res_dropin_tot/Sample_Res_dropin_tot
gen Umemp_Res_Rate_dropin_tot=Unemp_Res_dropin_tot/Sample_Res_dropin_tot
gen NILF_Res_Rate_dropin_tot=NILF_Res_dropin_tot/Sample_Res_dropin_tot

*same for BLS weights
gen Emp_Res_BLS_dropin_tot=Emp_Res_BLS_1_dropin+Emp_Res_BLS_2_dropin+Emp_Res_BLS_3_dropin+Emp_Res_BLS_5_dropin+Emp_Res_BLS_6_dropin+Emp_Res_BLS_7_dropin
gen Unemp_Res_BLS_dropin_tot=Unemp_Res_BLS_1_dropin+Unemp_Res_BLS_2_dropin+Unemp_Res_BLS_3_dropin+Unemp_Res_BLS_5_dropin+Unemp_Res_BLS_6_dropin+Unemp_Res_BLS_7_dropin
gen NILF_Res_BLS_dropin_tot=NILF_Res_BLS_1_dropin+NILF_Res_BLS_2_dropin+NILF_Res_BLS_3_dropin+NILF_Res_BLS_5_dropin+NILF_Res_BLS_6_dropin+NILF_Res_BLS_7_dropin
gen Sample_Res_BLS_dropin_tot=Sample_Res_BLS_1_dropin+Sample_Res_BLS_2_dropin+Sample_Res_BLS_3_dropin+Sample_Res_BLS_5_dropin+Sample_Res_BLS_6_dropin+Sample_Res_BLS_7_dropin

gen Emp_Res_BLS_dropin_Rate_tot=Emp_Res_BLS_dropin_tot/Sample_Res_BLS_dropin_tot
gen Umemp_Res_BLS_dropin_Rate_tot=Unemp_Res_BLS_dropin_tot/Sample_Res_BLS_dropin_tot
gen NILF_Res_BLS_dropin_Rate_tot=NILF_Res_BLS_dropin_tot/Sample_Res_BLS_dropin_tot



*need to fill the type As because they don't overlap.
egen Emp_TypeA_1_dropin_fill=max(Emp_TypeA_1_dropin)
egen Emp_TypeA_2_dropin_fill=max(Emp_TypeA_2_dropin)
egen Emp_TypeA_3_dropin_fill=max(Emp_TypeA_3_dropin)
egen Emp_TypeA_4_dropin_fill=max(Emp_TypeA_4_dropin)
egen Emp_TypeA_5_dropin_fill=max(Emp_TypeA_5_dropin)
egen Emp_TypeA_6_dropin_fill=max(Emp_TypeA_6_dropin)
egen Emp_TypeA_7_dropin_fill=max(Emp_TypeA_7_dropin)

egen Unemp_TypeA_1_dropin_fill=max(Unemp_TypeA_1_dropin)
egen Unemp_TypeA_2_dropin_fill=max(Unemp_TypeA_2_dropin)
egen Unemp_TypeA_3_dropin_fill=max(Unemp_TypeA_3_dropin)
egen Unemp_TypeA_4_dropin_fill=max(Unemp_TypeA_4_dropin)
egen Unemp_TypeA_5_dropin_fill=max(Unemp_TypeA_5_dropin)
egen Unemp_TypeA_6_dropin_fill=max(Unemp_TypeA_6_dropin)
egen Unemp_TypeA_7_dropin_fill=max(Unemp_TypeA_7_dropin)

egen NILF_TypeA_1_dropin_fill=max(NILF_TypeA_1_dropin)
egen NILF_TypeA_2_dropin_fill=max(NILF_TypeA_2_dropin)
egen NILF_TypeA_3_dropin_fill=max(NILF_TypeA_3_dropin)
egen NILF_TypeA_4_dropin_fill=max(NILF_TypeA_4_dropin)
egen NILF_TypeA_5_dropin_fill=max(NILF_TypeA_5_dropin)
egen NILF_TypeA_6_dropin_fill=max(NILF_TypeA_6_dropin)
egen NILF_TypeA_7_dropin_fill=max(NILF_TypeA_7_dropin)

egen Sample_TypeA_1_dropin_fill=max(Sample_TypeA_1_dropin)
egen Sample_TypeA_2_dropin_fill=max(Sample_TypeA_2_dropin)
egen Sample_TypeA_3_dropin_fill=max(Sample_TypeA_3_dropin)
egen Sample_TypeA_4_dropin_fill=max(Sample_TypeA_4_dropin)
egen Sample_TypeA_5_dropin_fill=max(Sample_TypeA_5_dropin)
egen Sample_TypeA_6_dropin_fill=max(Sample_TypeA_6_dropin)
egen Sample_TypeA_7_dropin_fill=max(Sample_TypeA_7_dropin)

gen Emp_TypeA_dropin_tot=Emp_TypeA_1_dropin_fill+Emp_TypeA_2_dropin_fill+Emp_TypeA_3_dropin_fill+Emp_TypeA_5_dropin_fill+Emp_TypeA_6_dropin_fill+Emp_TypeA_7_dropin_fill
gen Unemp_TypeA_dropin_tot=Unemp_TypeA_1_dropin_fill+Unemp_TypeA_2_dropin_fill+Unemp_TypeA_3_dropin_fill+Unemp_TypeA_5_dropin_fill+Unemp_TypeA_6_dropin_fill+Unemp_TypeA_7_dropin_fill
gen NILF_TypeA_dropin_tot=NILF_TypeA_1_dropin_fill+NILF_TypeA_2_dropin_fill+NILF_TypeA_3_dropin_fill+NILF_TypeA_5_dropin_fill+NILF_TypeA_6_dropin_fill+NILF_TypeA_7_dropin_fill
gen Sample_TypeA_dropin_tot=Sample_TypeA_1_dropin_fill+Sample_TypeA_2_dropin_fill+Sample_TypeA_3_dropin_fill+Sample_TypeA_5_dropin_fill+Sample_TypeA_6_dropin_fill+Sample_TypeA_7_dropin_fill


*This generates the values in the nonresponse column in Panel B Table 1
gen Emp_TypeA_Rate_dropin_tot=Emp_TypeA_dropin_tot/Sample_TypeA_dropin_tot
gen Umemp_TypeA_Rate_dropin_tot=Unemp_TypeA_dropin_tot/Sample_TypeA_dropin_tot
gen NILF_TypeA_Rate_dropin_tot=NILF_TypeA_dropin_tot/Sample_TypeA_dropin_tot

*same for BLS weights
egen Emp_TypeA_BLS_1_dropin_fill=max(Emp_TypeA_BLS_1_dropin)
egen Emp_TypeA_BLS_2_dropin_fill=max(Emp_TypeA_BLS_2_dropin)
egen Emp_TypeA_BLS_3_dropin_fill=max(Emp_TypeA_BLS_3_dropin)
egen Emp_TypeA_BLS_4_dropin_fill=max(Emp_TypeA_BLS_4_dropin)
egen Emp_TypeA_BLS_5_dropin_fill=max(Emp_TypeA_BLS_5_dropin)
egen Emp_TypeA_BLS_6_dropin_fill=max(Emp_TypeA_BLS_6_dropin)
egen Emp_TypeA_BLS_7_dropin_fill=max(Emp_TypeA_BLS_7_dropin)

egen Unemp_TypeA_BLS_1_dropin_fill=max(Unemp_TypeA_BLS_1_dropin)
egen Unemp_TypeA_BLS_2_dropin_fill=max(Unemp_TypeA_BLS_2_dropin)
egen Unemp_TypeA_BLS_3_dropin_fill=max(Unemp_TypeA_BLS_3_dropin)
egen Unemp_TypeA_BLS_4_dropin_fill=max(Unemp_TypeA_BLS_4_dropin)
egen Unemp_TypeA_BLS_5_dropin_fill=max(Unemp_TypeA_BLS_5_dropin)
egen Unemp_TypeA_BLS_6_dropin_fill=max(Unemp_TypeA_BLS_6_dropin)
egen Unemp_TypeA_BLS_7_dropin_fill=max(Unemp_TypeA_BLS_7_dropin)

egen NILF_TypeA_BLS_1_dropin_fill=max(NILF_TypeA_BLS_1_dropin)
egen NILF_TypeA_BLS_2_dropin_fill=max(NILF_TypeA_BLS_2_dropin)
egen NILF_TypeA_BLS_3_dropin_fill=max(NILF_TypeA_BLS_3_dropin)
egen NILF_TypeA_BLS_4_dropin_fill=max(NILF_TypeA_BLS_4_dropin)
egen NILF_TypeA_BLS_5_dropin_fill=max(NILF_TypeA_BLS_5_dropin)
egen NILF_TypeA_BLS_6_dropin_fill=max(NILF_TypeA_BLS_6_dropin)
egen NILF_TypeA_BLS_7_dropin_fill=max(NILF_TypeA_BLS_7_dropin)

egen Sample_TypeA_BLS_1_dropin_fill=max(Sample_TypeA_BLS_1_dropin)
egen Sample_TypeA_BLS_2_dropin_fill=max(Sample_TypeA_BLS_2_dropin)
egen Sample_TypeA_BLS_3_dropin_fill=max(Sample_TypeA_BLS_3_dropin)
egen Sample_TypeA_BLS_4_dropin_fill=max(Sample_TypeA_BLS_4_dropin)
egen Sample_TypeA_BLS_5_dropin_fill=max(Sample_TypeA_BLS_5_dropin)
egen Sample_TypeA_BLS_6_dropin_fill=max(Sample_TypeA_BLS_6_dropin)
egen Sample_TypeA_BLS_7_dropin_fill=max(Sample_TypeA_BLS_7_dropin)

gen Emp_TypeA_BLS_tot_dropin=Emp_TypeA_BLS_1_dropin_fill+Emp_TypeA_BLS_2_dropin_fill+Emp_TypeA_BLS_3_dropin_fill+Emp_TypeA_BLS_5_dropin_fill+Emp_TypeA_BLS_6_dropin_fill+Emp_TypeA_BLS_7_dropin_fill
gen Unemp_TypeA_BLS_tot_dropin=Unemp_TypeA_BLS_1_dropin_fill+Unemp_TypeA_BLS_2_dropin_fill+Unemp_TypeA_BLS_3_dropin_fill+Unemp_TypeA_BLS_5_dropin_fill+Unemp_TypeA_BLS_6_dropin_fill+Unemp_TypeA_BLS_7_dropin_fill
gen NILF_TypeA_BLS_tot_dropin=NILF_TypeA_BLS_1_dropin_fill+NILF_TypeA_BLS_2_dropin_fill+NILF_TypeA_BLS_3_dropin_fill+NILF_TypeA_BLS_5_dropin_fill+NILF_TypeA_BLS_6_dropin_fill+NILF_TypeA_BLS_7_dropin_fill
gen Sample_TypeA_BLS_tot_dropin=Sample_TypeA_BLS_1_dropin_fill+Sample_TypeA_BLS_2_dropin_fill+Sample_TypeA_BLS_3_dropin_fill+Sample_TypeA_BLS_5_dropin_fill+Sample_TypeA_BLS_6_dropin_fill+Sample_TypeA_BLS_7_dropin_fill

gen Emp_TypeA_BLS_Rate_tot_dropin=Emp_TypeA_BLS_tot_dropin/Sample_TypeA_BLS_tot_dropin
gen Umemp_TypeA_BLS_Rate_tot_dropin=Unemp_TypeA_BLS_tot_dropin/Sample_TypeA_BLS_tot_dropin
gen NILF_TypeA_BLS_Rate_tot_dropin=NILF_TypeA_BLS_tot_dropin/Sample_TypeA_BLS_tot_dropin


