*** How Does the Dramatic Rise of CPS Nonresponse Impact Labor Market Indicators? 
*** Bernhardt, Munro, Wolcott 
*** Journal of Applied Econometrics 
*** 2023 

*** flows2_flows_corr.do

** Flows & Corrections 2 - Function Script 
** (a) Basic Labor Force Status Flows Corrections 
** Note: also computes rogue weights to export with cpsb_filledin_flows2_$month for Recreating BLS Weights.do

preserve 

use Data/cpsb$month , clear  
gen date = $month 

quietly count if HRINTSTA == 2 // Determines number of Type-A NR Households 
scalar quantity_typeA = r(N) // Provides the numerator for the rogue weights 

keep if status != -1 
*keep date status gestfips hrhhid hrhhid2 line mis 
keep date status gestfips hrhhid hrhhid2 line mis race age sex PEHSPNON PWCMPWGT //keeping additional variables for flows2 + demographic adjustment for responders

save Data/status_responders_$month , replace 

* Type-A NR, forward direction 

use Data/cpsb$month , clear 
gen date = $month 
keep if HRINTSTA == 2 // keeps only type-A NRs
keep gestfips hrhhid hrhhid2 date mis // allows LF status to be over-written by later month's value; keeps mis so not over-written 

quietly merge 1:m gestfips hrhhid hrhhid2 using Data/cpsb$month_next , keep(3) nogen 
// Limits to only those in  next month who were a type-A NR in  current month 
drop if status == -1 // Drops those with no LF status in  next month 

** Renaming variables of partially responding HH before NR
rename status status_for 
rename race race_for
rename age age_for
rename sex sex_for
rename PEHSPNON PEHSPNON_for
rename PWCMPWGT PWCMPWGT_for
 
save Data/typeA_for_$month , replace 

* Type-A NR, backwards direction 

use Data/cpsb$month , clear 
gen date = $month 
keep if HRINTSTA == 2 
keep gestfips hrhhid hrhhid2 date mis 

quietly merge 1:m gestfips hrhhid hrhhid2 using Data/cpsb$month_prev , keep(3) nogen  
drop if status == -1 

** Renaming variables of partially responding HH before NR
rename status status_back 
rename race race_back
rename age age_back
rename sex sex_back
rename PEHSPNON PEHSPNON_back
rename PWCMPWGT PWCMPWGT_back
 
save Data/typeA_back_$month , replace 


merge 1:1 gestfips hrhhid hrhhid2 line using Data/typeA_for_$month , nogen
*keep date gestfips hrhhid hrhhid2 line status_for status_back mis  

** Figuring out which Forward or Backwards characteristics to keep.  If different, keep backwards 

foreach var in race age sex PEHSPNON PWCMPWGT {
replace `var'_for=. if `var'_for<0	
replace `var'_back=. if `var'_back<0	
gen `var'=`var'_back
replace `var'=`var'_for if `var'_back==. //If characteristics of individual before and after NR are non-missing privilege back
}

keep date status_for status_back gestfips hrhhid hrhhid2 line mis race age sex PEHSPNON PWCMPWGT

** Generates weights for correction 3
bys gestfips hrhhid hrhhid2: gen Count = _n
quietly count if Count == 1 // Occurs once per HH. Counts # of flows matched HH
scalar quantity_matched = r(N) // Provides denominator for rogue weights 
scalar rogue_weight_value = quantity_typeA / quantity_matched // Rogue weight value
gen rogue_weight = rogue_weight_value // fills in for every partially responding HH

merge 1:1 gestfips hrhhid hrhhid2 line using Data/status_responders_$month , nogen



* Employment Status Variables 

gen employed = . 
replace employed = 0 if status <= 7 
replace employed = 1 if status == 1 | status == 2 

gen unemployed = . 
replace unemployed = 0 if status <= 7 
replace unemployed = 1 if status == 3 | status == 4 

gen nilf = . 
replace nilf = 1 if status <= 7
replace nilf = 0 if status <= 4 

foreach x in for back { 

gen employed_`x' = . 
replace employed_`x' = 0 if status_`x' <= 7 
replace employed_`x' = 1 if status_`x' == 1 | status_`x' == 2 

gen unemployed_`x' = . 
replace unemployed_`x' = 0 if status_`x' <= 7 
replace unemployed_`x' = 1 if status_`x' == 3 | status_`x' == 4 

gen nilf_`x' = . 
replace nilf_`x' = 1 if status_`x' <= 7
replace nilf_`x' = 0 if status_`x' <= 4 

}

gen year = int(date/100)
merge m:1 year using Data/flows_by_year_wide , keep(3) nogen 

*

foreach state in employed unemployed nilf { 

gen `state'_naive = 0 
replace `state'_naive = 1 if `state' == 1 
replace `state'_naive = 1 if `state'_for == 1 & missing(`state'_back) 
replace `state'_naive = 1 if `state'_back == 1 & missing(`state'_for) 
replace `state'_naive = 1 if `state'_for == 1 & `state'_back == 1
replace `state'_naive = 0.5 if `state'_for == 1 & `state'_back == 0 
replace `state'_naive = 0.5 if `state'_for == 0 & `state'_back == 1
replace `state'_naive = 0 if `state'_for == 0 & `state'_back == 0 

}

* 

* Forwards Flows Corrections 

gen employed_flows_for = 0 
replace employed_flows_for = 1 if employed == 1 // Responders

forvalues x = 1/7 {

local y = `x' + 1 

replace employed_flows_for = EE`y'_`x' if employed_for == 1 & mis == `x' // Case focuses on individuals in mis `x' who are employed in mis `x'+1 (e.g. mis `y'). The flow tells us the probability they were previously employed when they didn't respond, so we assign them as being partially employed where the flow indicates the chance they're employed 
replace employed_flows_for = UE`y'_`x' if unemployed_for == 1 & mis == `x' // UE`y'_`x' is the chance that someone unemployed in month 2 would have been employed in month 1 
replace employed_flows_for = NE`y'_`x' if nilf_for == 1 & mis == `x' 

}

* 

gen unemployed_flows_for = 0 
replace unemployed_flows_for = 1 if unemployed == 1 // Responders 

forvalues x = 1/7 {

local y = `x' + 1 

replace unemployed_flows_for = EU`y'_`x' if employed_for == 1 & mis == `x' // EU`y'_`x' indicates the chance someone was unemployed in `x' if they were employed in `y'
replace unemployed_flows_for = UU`y'_`x' if unemployed_for == 1 & mis == `x' 
replace unemployed_flows_for = NU`y'_`x' if nilf_for == 1 & mis == `x' 

}

* 

gen nilf_flows_for = 0 
replace nilf_flows_for = 1 if nilf == 1 // Responders 

foreach x in 1 2 3 4 5 6 7 { 

local y = `x' + 1 

replace nilf_flows_for = EN`y'_`x' if employed_for == 1 & mis == `x' 
replace nilf_flows_for = UN`y'_`x' if unemployed_for == 1 & mis == `x' 
replace nilf_flows_for = NN`y'_`x' if nilf_for == 1 & mis == `x' 

}

gen total_probability_for = employed_flows_for + unemployed_flows_for + nilf_flows_for
quietly sum total_probability_for 
scalar total_probability_for_$month = r(mean) 

* Backwards Flows Corrections 

gen employed_flows_back = 0 
replace employed_flows_back = 1 if employed == 1

forvalues x = 1/7 { 

local y = `x' + 1 

replace employed_flows_back = EE`x'_`y' if employed_back == 1 & mis == `y' // EE`x'_`y' indicates the chance a person employed in mis `x' is still employed in mis `y'. 
replace employed_flows_back = UE`x'_`y' if unemployed_back == 1 & mis == `y' 
replace employed_flows_back = NE`x'_`y' if nilf_back == 1 & mis == `y' 

}

* 

gen unemployed_flows_back = 0 
replace unemployed_flows_back = 1 if unemployed == 1 

forvalues x = 1/7 {

local y = `x' + 1 

replace unemployed_flows_back = EU`x'_`y' if employed_back == 1 & mis == `y' 
replace unemployed_flows_back = UU`x'_`y' if unemployed_back == 1 & mis == `y' 
replace unemployed_flows_back = NU`x'_`y' if nilf_back == 1 & mis == `y' 

}

* 

gen nilf_flows_back = 0 
replace nilf_flows_back = 1 if nilf == 1 

forvalues x = 1/7 {

local y = `x' + 1 

replace nilf_flows_back = EN`x'_`y' if employed_back == 1 & mis == `y' 
replace nilf_flows_back = UN`x'_`y' if unemployed_back == 1 & mis == `y' 
replace nilf_flows_back = NN`x'_`y' if nilf_back == 1 & mis == `y' 

}

gen total_probability_back = employed_flows_back + unemployed_flows_back + nilf_flows_back
quietly sum total_probability_back
scalar total_probability_back_$month = r(mean) 

* Taking the Average of Forward & Backwards Flow Corrections 
foreach state in employed unemployed nilf { 

gen `state'_flows = 0 
replace `state'_flows = `state'_flows_for if missing(status_back) & missing(status) 
replace `state'_flows = `state'_flows_back if missing(status_for) & missing(status)
replace `state'_flows = `state' if !missing(status) 
replace `state'_flows = (`state'_flows_for + `state'_flows_back) / 2 if !missing(status_for) & !missing(status_back) 

}

** Saving data for flows2 + demographic correction 
save Data/cpsb_filledin_flows2_$month , replace 

** Creating labor force statistics
egen E_raw = sum(employed) 
egen U_raw = sum(unemployed)
egen N_raw = sum(nilf) 

gen unemployment_raw = U_raw / (U_raw + E_raw) 
gen lf_part_raw = (E_raw + U_raw ) / (E_raw + U_raw + N_raw) 
gen emp_pop_raw = E_raw/(E_raw + U_raw + N_raw) 

egen E_naive = sum(employed_naive) 
egen U_naive = sum(unemployed_naive) 
egen N_naive = sum(nilf_naive) 

gen unemployment_naive = U_naive / (E_naive + U_naive) 
gen lf_part_naive = (E_naive + U_naive ) / ( E_naive + U_naive + N_naive ) 
gen emp_pop_naive = E_naive/( E_naive + U_naive + N_naive )

egen E_flows = sum(employed_flows) 
egen U_flows = sum(unemployed_flows) 
egen N_flows = sum(nilf_flows) 

gen unemployment_flows = U_flows / (U_flows + E_flows) 
gen lf_part_flows = (E_flows + U_flows) / (E_flows + U_flows + N_flows) 
gen emp_pop_flows = E_flows/(E_flows + U_flows + N_flows)

collapse (mean) unemployment* lf_part* emp_pop* date year

save Data/corrected_$month , replace 

restore 

append using Data/corrected_$month 
