*** How Does the Dramatic Rise of CPS Nonresponse Impact Labor Market Indicators? 
*** Bernhardt, Munro, Wolcott 
*** Journal of Applied Econometrics 
*** 2023 

*** TimeSeriesPartial_vs_NeverResponse.do 
*** Creates "Figure 2: Nonresponding Households With and Without Adjacent Information"
*** See lines 70-77 for graph production and exporting  


use "Data/eight_panel_hh.dta"
egen hhidvar = group(gestfips hrhhid hrhhid2)

reshape long mdate typeA refused, i(hhidvar) j(MIS)

gen Occ_Dwelling_MIS1=1 if MIS==1 & HRINTSTA1<=2
gen Occ_Dwelling_MIS2=1 if MIS==2 & HRINTSTA2<=2
gen Occ_Dwelling_MIS3=1 if MIS==3 & HRINTSTA3<=2
gen Occ_Dwelling_MIS4=1 if MIS==4 & HRINTSTA4<=2
gen Occ_Dwelling_MIS5=1 if MIS==5 & HRINTSTA5<=2
gen Occ_Dwelling_MIS6=1 if MIS==6 & HRINTSTA6<=2
gen Occ_Dwelling_MIS7=1 if MIS==7 & HRINTSTA7<=2
gen Occ_Dwelling_MIS8=1 if MIS==8 & HRINTSTA8<=2

bysort mdate: egen Occ_Dwelling_MIS1_Tot=sum(Occ_Dwelling_MIS1)
bysort mdate: egen Occ_Dwelling_MIS2_Tot=sum(Occ_Dwelling_MIS2)
bysort mdate: egen Occ_Dwelling_MIS3_Tot=sum(Occ_Dwelling_MIS3)
bysort mdate: egen Occ_Dwelling_MIS4_Tot=sum(Occ_Dwelling_MIS4)
bysort mdate: egen Occ_Dwelling_MIS5_Tot=sum(Occ_Dwelling_MIS5)
bysort mdate: egen Occ_Dwelling_MIS6_Tot=sum(Occ_Dwelling_MIS6)
bysort mdate: egen Occ_Dwelling_MIS7_Tot=sum(Occ_Dwelling_MIS7)
bysort mdate: egen Occ_Dwelling_MIS8_Tot=sum(Occ_Dwelling_MIS8)

gen Occ_Dwelling_Tot=Occ_Dwelling_MIS1_Tot+Occ_Dwelling_MIS2_Tot+Occ_Dwelling_MIS3_Tot+Occ_Dwelling_MIS4_Tot+Occ_Dwelling_MIS5_Tot+Occ_Dwelling_MIS6_Tot+Occ_Dwelling_MIS7_Tot+Occ_Dwelling_MIS8_Tot


gen MIS1_NoMatchTypeA=1 if MIS==1 & HRINTSTA1==2 &HRINTSTA2==2
gen MIS2_NoMatchTypeA=1 if MIS==2 & HRINTSTA2==2 &HRINTSTA1==2 &HRINTSTA3==2
gen MIS3_NoMatchTypeA=1 if MIS==3 & HRINTSTA3==2 &HRINTSTA2==2 &HRINTSTA4==2
*don't match across 8 month survey gap between MIS 4 and 5
gen MIS4_NoMatchTypeA=1 if MIS==4 & HRINTSTA4==2 &HRINTSTA3==2 
*don't match across 8 month survey gap between MIS 5 and 4
gen MIS5_NoMatchTypeA=1 if MIS==5 & HRINTSTA5==2 &HRINTSTA6==2
gen MIS6_NoMatchTypeA=1 if MIS==6 & HRINTSTA6==2 &HRINTSTA5==2 &HRINTSTA7==2
gen MIS7_NoMatchTypeA=1 if MIS==7 & HRINTSTA7==2 &HRINTSTA6==2 &HRINTSTA8==2
gen MIS8_NoMatchTypeA=1 if MIS==8 & HRINTSTA8==2 &HRINTSTA7==2

bysort mdate: egen MIS1_NoMatchTypeA_Tot=sum(MIS1_NoMatchTypeA)
bysort mdate: egen MIS2_NoMatchTypeA_Tot=sum(MIS2_NoMatchTypeA)
bysort mdate: egen MIS3_NoMatchTypeA_Tot=sum(MIS3_NoMatchTypeA)
bysort mdate: egen MIS4_NoMatchTypeA_Tot=sum(MIS4_NoMatchTypeA)
bysort mdate: egen MIS5_NoMatchTypeA_Tot=sum(MIS5_NoMatchTypeA)
bysort mdate: egen MIS6_NoMatchTypeA_Tot=sum(MIS6_NoMatchTypeA)
bysort mdate: egen MIS7_NoMatchTypeA_Tot=sum(MIS7_NoMatchTypeA)
bysort mdate: egen MIS8_NoMatchTypeA_Tot=sum(MIS8_NoMatchTypeA)

gen NoMatchTypeA_Tot=MIS1_NoMatchTypeA_Tot+MIS2_NoMatchTypeA_Tot+MIS3_NoMatchTypeA_Tot+MIS4_NoMatchTypeA_Tot+MIS5_NoMatchTypeA_Tot+MIS6_NoMatchTypeA_Tot+MIS7_NoMatchTypeA_Tot+MIS8_NoMatchTypeA_Tot

bysort mdate: egen TotTypeA=sum(typeA)

gen MatchTypeA_Tot=TotTypeA-NoMatchTypeA_Tot

gen Share_NoMatchTypeA=NoMatchTypeA_Tot/Occ_Dwelling_Tot
gen Share_MatchTypeA=MatchTypeA_Tot/Occ_Dwelling_Tot

bysort mdate: gen DateID=_n

set scheme s2color

line Share_NoMatchTypeA Share_MatchTypeA mdate ///
	if DateID==1 & mdate>=tm(1999m4) & mdate<=tm(2019m6), ///
	legend(order( 1 "Without" 2 "With" ) position(10) ring(0) cols(1) ///
	region(fcolor(none) lstyle(none))) lcolor("red" "gray") ///
	ytitle("Share of Occupied Dwellings") xtitle("") lp("shortdash" "solid") ///
	plotregion(fcolor(white)) graphregion(fcolor(white) lcolor(white)) ///
	ylabel(0(.02).12, angle(0)) yscale(range(.01 .14))
graph export "Graphs/Share_Match_UnMatched_NRs.eps", replace


