*** How Does the Dramatic Rise of CPS Nonresponse Impact Labor Market Indicators? 
*** Bernhardt, Munro, Wolcott 
*** Journal of Applied Econometrics 
*** 2023 

*** aggregate_response_rates.do 
*** Generates "Figure 1: CPS Nonresponse Rates of Occupied Dwellings" 
*** See Line 148 for graph output command 

** Aggregate National Non-Response for Type A only 

clear
gen date = . 
save Data/aggregate_national_nonresponse.dta, replace 

local x = 199801 

while `x' <= 202107 { 
	
preserve 

use Data/cpsb`x', clear 

collapse (mean) HRINTSTA , by(gestfips hrhhid hrhhid2) // Limit 1 obs. per household 

drop if HRINTSTA>2 //dropping type B and C

gen typeA = 0 
replace typeA = 1 if HRINTSTA == 2

collapse (mean) typeA  // Gets a national average for each category
gen date = `x' 

tempfile temp`x'
save `temp`x'' , replace  

restore 

append using `temp`x''

local x = `x' + 1 
if (`x'-13)/100 == int((`x'-13)/100) {
    local x = `x' + 88
    noisily display (`x'-1)/100
	}
	
}

gen date_num = date - int(date/100)*100
replace date_num = date_num + int(date/100)*12 - 1998*12
gen mdate = m(1998m1) + date_num - 1

cap tsset mdate, m 


foreach x in A{ 
	replace type`x' = 100 * type`x'
	label variable type`x' "Type `x' Non-Response"
}
label variable mdate "Survey Month"

save Data/aggregate_national_nonresponse, replace


 

** Aggregate National Type A 

clear
gen date = . 
save Data/aggregate_national_typea.dta, replace 

local x = 199801 

while `x' <= 202107 { 
	
preserve 

use Data/cpsb`x'.dta, clear 

collapse (mean) HRINTSTA HUTYPEA , by(gestfips hrhhid hrhhid2) // 1 obs. per household 

drop if HRINTSTA>2 //dropping type B and C


forvalues y = 1/6 { 
	
	gen A`y' = 0
	replace A`y' = 1 if HUTYPEA == `y'	
	
} // Generates a variable for each category of type A non-response 

collapse (mean) A1 A2 A3 A4 A5 A6 // Takes average for entire country 
gen date = `x' 

tempfile temp`x'
save `temp`x'' , replace  

restore 

append using `temp`x''

local x = `x' + 1 
if (`x'-13)/100 == int((`x'-13)/100) {
    local x = `x' + 88
    noisily display (`x'-1)/100
	}

}

gen date_num = date - int(date/100)*100
replace date_num = date_num + int(date/100)*12 - 1998*12
gen mdate = m(1998m1) + date_num - 1

cap tsset mdate, m 

local y = 1 
foreach z in "No One Home" "Temporarily Absent" Refused "Language Barrier" "Unable to Locate" "Other Occupied" { 
	
	label variable A`y' "`z'"
	
	replace A`y' = 100 * A`y' 
	
	local y = `y' + 1 
	
}

label variable mdate "Survey Month"

save Data/aggregate_national_typea, replace 
 

use Data/aggregate_national_nonresponse, clear
merge 1:1 date using Data/aggregate_national_typea.dta

set scheme s2color

* Setting colors
local mydarkred ="153 0 0" 
local myred = "240 0 0"
local mygray= "180 180 180"
local mynavy= "0 0 100"


twoway area typeA A3 mdate if mdate > ym(1998,01), fcolor("`mygray'" blue) lcolor(gray "`mynavy'" ) ///
legend(order( 1 "All Other Reasons" 2 "Refusals" ) position(10) ring(0) cols(1) region(fcolor(none) lstyle(none))) ///
yscale(range(0 35)) ylabel( 0 "0%" 10 "10%" 20 "20%"  30 "30%",angle(0)) xtitle("") ///
plotregion(fcolor(white)) graphregion(fcolor(white) lcolor(white)) ytitle("") ylabel(, angle(0)) 
graph export "Graphs/Motivation.eps", replace

