*** How Does the Dramatic Rise of CPS Nonresponse Impact Labor Market Indicators? 
*** Bernhardt, Munro, Wolcott 
*** Journal of Applied Econometrics 
*** 2023 

*** eight_panel_generate.do 
*** Generates a matched panel of all individuals and HH across all sample months 
*** Key file Data/eight_panel_complete.dta saved on Line 450 

*

*** KEY ***
* Responders: _1
* Non-Responders: _2

clear 

** Separating Responders & Non-Responders **
forvalues x = 1/8 {

use Data/match_merge_mis`x'.dta , clear 
drop if date < 199801
keep if HRINTSTA`x' == 1 // Keeps responders only 

tempfile mis`x'_1
save `mis`x'_1', replace

* 

use Data/match_merge_mis`x'.dta , clear 
drop if date < 199801
keep if HRINTSTA`x' != 1 // Keeps non-responders only 

tempfile mis`x'_2
save `mis`x'_2', replace

}

///  Merging MIS Files to Output every combination 8x2 combination of Responders(1) 
/// and Non-responders(2), where we always start with responders   

	foreach x2 in 1 2 {
		foreach x3 in 1 2 {
			foreach x4 in 1 2 {
				foreach x5 in 1 2 {
					foreach x6 in 1 2 {
						foreach x7 in 1 2 {
							foreach x8 in 1 2 {

	*** MIS 1 = Responders *** 
	
	use `mis1_1' // initial file is the *responders* in month 1
	di `x2' `x2' `x4' `x5' `x6' `x7' `x8' 
	
	************************ MIS 2 ************************
	di "Mis 2: `x2'"
	
	//isolates the responders and does a 1:1 merge
	if `x2'==1  { 
	merge 1:1 gestfips hrhhid hrhhid2 line using `mis2_`x2'' , keep(3)
	drop _merge
	}
	
	//isolates the non-responders and does a m:1 merge
	else { 
	merge m:1 gestfips hrhhid hrhhid2 using `mis2_`x2'' , keep(3)
	drop _merge
	}
	
	************************ MIS 3 ************************
	di "Mis 3: `x3'"
	
	//isolates the responders and does a 1:1 merge
	if `x3'==1  { 
	merge 1:1 gestfips hrhhid hrhhid2 line using `mis3_`x3'' , keep(3)
	drop _merge
	}
	
	//isolates the non-responders and does a m:1 merge
	else { 
	merge m:1 gestfips hrhhid hrhhid2 using `mis3_`x3'' , keep(3)
	drop _merge
	}
	
	************************ MIS 4 ************************
	di "Mis 4: `x4'"
	
	//isolates the responders and does a 1:1 merge
	if `x4'==1    { 
	merge 1:1 gestfips hrhhid hrhhid2 line using `mis4_`x4'' , keep(3)
	drop _merge
	}
	
	//isolates the non-responders and does a m:1 merge
	else { 
	merge m:1 gestfips hrhhid hrhhid2 using `mis4_`x4'' , keep(3)
	drop _merge
	}
	
	************************ MIS 5 ************************
	di "Mis 5: `x5'"
	
	//isolates the responders and does a 1:1 merge
	if `x5'==1    { 
	merge 1:1 gestfips hrhhid hrhhid2 line using `mis5_`x5'' , keep(3)
	drop _merge
	}
	
	//isolates the non-responders and does a m:1 merge
	else { 
	merge m:1 gestfips hrhhid hrhhid2 using `mis5_`x5'' , keep(3)
	drop _merge
	}
	
	************************ MIS 6 ************************
	di "Mis 6: `x6'"
	
	//isolates the responders and does a 1:1 merge
	if `x6'==1    { 
	merge 1:1 gestfips hrhhid hrhhid2 line using `mis6_`x6'' , keep(3)
	drop _merge
	}
	
	//isolates the non-responders and does a m:1 merge
	else { 
	merge m:1 gestfips hrhhid hrhhid2 using `mis6_`x6'' , keep(3)
	drop _merge
	}
	
	************************ MIS 7 ************************
	di "Mis 7: `x7'"
	
	//isolates the responders and does a 1:1 merge
	if `x7'==1    { 
	merge 1:1 gestfips hrhhid hrhhid2 line using `mis7_`x7'' , keep(3) 
	drop _merge
	}
	
	//isolates the non-responders and does a m:1 merge
	else { 
	merge m:1 gestfips hrhhid hrhhid2 using `mis7_`x7'' , keep(3)
	drop _merge
	}
	
	************************ MIS 8 ************************
	di "Mis 8: `x8'"
	
	//isolates the responders and does a 1:1 merge
	if `x8'==1    { 
	merge 1:1 gestfips hrhhid hrhhid2 line using `mis8_`x8'' , keep(3)
	drop _merge
	}
	
	//isolates the non-responders and does a m:1 merge
	else { 
	merge m:1 gestfips hrhhid hrhhid2 using `mis8_`x8'' , keep(3)
	drop _merge
	}
	
	************************ Saving ************************
	
	tempfile temp_1_`x2'_`x3'_`x4'_`x5'_`x6'_`x7'_`x8'
	save `temp_1_`x2'_`x3'_`x4'_`x5'_`x6'_`x7'_`x8'' , replace
	
							}
						}
					}
				}
			}
		}
	}

/// Appending Them All Together Using a Loop
clear
gen date = . 

	foreach x2 in 1 2 {
		foreach x3 in 1 2 {
			foreach x4 in 1 2 {
				foreach x5 in 1 2 {
					foreach x6 in 1 2 {
						foreach x7 in 1 2 {
							foreach x8 in 1 2 {
			
append using `temp_1_`x2'_`x3'_`x4'_`x5'_`x6'_`x7'_`x8''


							}
						}
					}
				}
			}
		}
	}
	
save Data/eight_panel_R1.dta, replace 

***

*

*** KEY ***
* Responders: _1
* Non-Responders: _2

clear

	foreach x2 in 1 2 {
		foreach x3 in 1 2 {
			foreach x4 in 1 2 {
				foreach x5 in 1 2 {
					foreach x6 in 1 2 {
						foreach x7 in 1 2 {
							foreach x8 in 1 2 {
	
	*** MIS 1 = Non-Responders ***
			
	use `mis1_2' , clear // initial file is non-responders in month 1
	drop line 
	
	di `x2' `x2' `x4' `x5' `x6' `x7' `x8' 
			
	************************ MIS 2 ************************
	
	// matches mis1 non-responders with mis2 responders (1:m)
	if `x2'==1  { 
	merge 1:m gestfips hrhhid hrhhid2 using `mis2_`x2'' , keep(3)
	drop _merge
	}
	
	//isolates the non-responders and does a 1:1 merge
	else { 
	merge 1:1 gestfips hrhhid hrhhid2 using `mis2_`x2'' , keep(3)
	drop _merge line 
	}
	
	************************ MIS 3 ************************
	
	if `x2' ==1 {
		if `x3'==1  { 
		merge 1:1 gestfips hrhhid hrhhid2 line using `mis3_`x3'' , keep(3)
		drop _merge
		}
	
		//isolates the non-responders and does a m:1 merge
		else { 
		merge m:1 gestfips hrhhid hrhhid2 using `mis3_`x3'' , keep(3)
		drop _merge
		}
		}
	
	else {
		if `x3' ==1 {
		merge 1:m gestfips hrhhid hrhhid2 using `mis3_`x3'' , keep(3)
		drop _merge
		}
		
		else {
		merge 1:1 gestfips hrhhid hrhhid2 using `mis3_`x3'' , keep(3)
		drop _merge line
		}
		}	
	
	************************ MIS 4 ************************
	
	if `x2'==1 | `x3'==1 {
		if `x4'==1  { 
		merge 1:1 gestfips hrhhid hrhhid2 line using `mis4_`x4'' , keep(3)
		drop _merge
		}
	
		//isolates the non-responders and does a m:1 merge
		else { 
		merge m:1 gestfips hrhhid hrhhid2 using `mis4_`x4'' , keep(3)
		drop _merge
		}
		}
	
	else {
		if `x4' ==1 {
		merge 1:m gestfips hrhhid hrhhid2 using `mis4_`x4'' , keep(3)
		drop _merge
		}
		
		else {
		merge 1:1 gestfips hrhhid hrhhid2 using `mis4_`x4'' , keep(3)
		drop _merge line 
		}
		}
		
	************************ MIS 5 ************************
	
	if `x2'==1 | `x3'==1 | `x4'==1 {
		if `x5'==1  { 
		merge 1:1 gestfips hrhhid hrhhid2 line using `mis5_`x5'' , keep(3)
		drop _merge
		}
	
		//isolates the non-responders and does a m:1 merge
		else { 
		merge m:1 gestfips hrhhid hrhhid2 using `mis5_`x5'' , keep(3)
		drop _merge
		}
		}
	
	else {
		if `x5' ==1 {
		merge 1:m gestfips hrhhid hrhhid2 using `mis5_`x5'' , keep(3)
		drop _merge
		}
		
		else {
		merge 1:1 gestfips hrhhid hrhhid2 using `mis5_`x5'' , keep(3)
		drop _merge line 
		}
		}
		
	************************ MIS 6 ************************
	
	if `x2'==1 | `x3'==1 | `x4'==1 | `x5'==1 {
		if `x6'==1  { 
		merge 1:1 gestfips hrhhid hrhhid2 line using `mis6_`x6'' , keep(3)
		drop _merge
		}
	
		//isolates the non-responders and does a m:1 merge
		else { 
		merge m:1 gestfips hrhhid hrhhid2 using `mis6_`x6'' , keep(3)
		drop _merge
		}
		}
	
	else {
		if `x6' ==1 {
		merge 1:m gestfips hrhhid hrhhid2 using `mis6_`x6'' , keep(3)
		drop _merge
		}
		
		else {
		merge 1:1 gestfips hrhhid hrhhid2 using `mis6_`x6'' , keep(3)
		drop _merge line 
		}
		}
		
	************************ MIS 7 ************************
	
	if `x2'==1 | `x3'==1 | `x4'==1 | `x5'==1 | `x6'==1 {
		if `x7'==1  { 
		merge 1:1 gestfips hrhhid hrhhid2 line using `mis7_`x7'' , keep(3)
		drop _merge
		}
	
		//isolates the non-responders and does a m:1 merge
		else { 
		merge m:1 gestfips hrhhid hrhhid2 using `mis7_`x7'' , keep(3)
		drop _merge
		}
		}
	
	else {
		if `x7' ==1 {
		merge 1:m gestfips hrhhid hrhhid2 using `mis7_`x7'' , keep(3)
		drop _merge
		}
		
		else {
		merge 1:1 gestfips hrhhid hrhhid2 using `mis7_`x7'' , keep(3)
		drop _merge line 
		}
	
		}
		
	************************ MIS 8 ************************
	
	if `x2'==1 | `x3'==1 | `x4'==1 | `x5'==1 | `x6'==1 | `x7'==1 {
		if `x8'==1  { 
		merge 1:1 gestfips hrhhid hrhhid2 line using `mis8_`x8'' , keep(3)
		drop _merge
		}
	
		//isolates the non-responders and does a m:1 merge
		else { 
		merge m:1 gestfips hrhhid hrhhid2 using `mis8_`x8'' , keep(3)
		drop _merge
		}
		}
	
	else {
		if `x8' ==1 {
		merge 1:m gestfips hrhhid hrhhid2 using `mis8_`x8'' , keep(3)
		drop _merge
		}
		
		else {
		merge 1:1 gestfips hrhhid hrhhid2 using `mis8_`x8'', keep(3)
		drop _merge line 
		}
		}
				
	************************ Saving ************************
	
	tempfile temp_2_`x2'_`x3'_`x4'_`x5'_`x6'_`x7'_`x8'
	save `temp_2_`x2'_`x3'_`x4'_`x5'_`x6'_`x7'_`x8'' , replace

							}
						}
					}
				}
			}
		}
	}

/// Appending Them All Together Using a Loop
clear
gen date = . 

	foreach x2 in 1 2 {
		foreach x3 in 1 2 {
			foreach x4 in 1 2 {
				foreach x5 in 1 2 {
					foreach x6 in 1 2 {
						foreach x7 in 1 2 {
							foreach x8 in 1 2 {
			
append using `temp_2_`x2'_`x3'_`x4'_`x5'_`x6'_`x7'_`x8''


							}
						}
					}
				}
			}
		}
	}
	
save Data/eight_panel_NR1.dta, replace 

* 

*** *** *** 

append using Data/eight_panel_R1

save Data/eight_panel_complete.dta, replace 


