*** How Does the Dramatic Rise of CPS Nonresponse Impact Labor Market Indicators? 
*** Bernhardt, Munro, Wolcott 
*** Journal of Applied Econometrics 
*** 2023 

*** eight_panel_generate_hh.do 
*** Generates panel of all households across all survey months 
*** Key file Data/eight_panel_hh.dta saved on Line 59  

* 

** Collecting all HH Found in all 8 Months-in-Sample (incl. non-responses)

clear

use Data/match_merge_mis1 , clear 
collapse (mean) HRINTSTA HUTYP* date* mdate* , by(gestfips hrhhid hrhhid2)
drop if date != int(date) // Problem observations exist for MIS 7 

forvalues mis = 2/8 {

preserve 

	use Data/match_merge_mis`mis' , clear 
	collapse (mean) HRINTSTA HUTYP* date* mdate* , by(gestfips hrhhid hrhhid2)
	drop if date != int(date) // Problem observations exist for MIS 7 
	
	tempfile mmm_hh`mis'
	save `mmm_hh`mis'' 
	
restore 

	merge 1:1 gestfips hrhhid hrhhid2 using `mmm_hh`mis'' , keep(3)
	drop _merge 
	
} 

*

** Generating Necessary Variables 

order gestfips hrhhid hrhhid2 HRINTSTA* HUTYPEA* HUTYPEB* HUTYPEC*
cap drop responded* type* total_*

forvalues mis = 1/8 { 

gen responded`mis' = (HRINTSTA`mis' == 1)
gen typeA`mis' = (HRINTSTA`mis' == 2)
gen typeB`mis' = (HRINTSTA`mis' == 3)
gen typeC`mis' = (HRINTSTA`mis' == 4)
gen refused`mis' = (HUTYPEA`mis' == 3)

}

foreach var in responded typeA typeB typeC refused {
	egen total_`var' = rowtotal(`var'*)
}

save Data/eight_panel_hh.dta , replace 

