*** How Does the Dramatic Rise of CPS Nonresponse Impact Labor Market Indicators? 
*** Bernhardt, Munro, Wolcott 
*** Journal of Applied Econometrics 
*** 2023 

*** flows_and_corrections1.do 
*** Obtains estimates of flows for the three labor force states 
*** Key files: Data/flows_raw.dta (Line 183), Data/flows_by_year_wide (Line 398)

* 

** Estimating Flows -- no cyclicality correction 

* Reminder: Interpret transitions carefully 
* EU1_2 is (unemployed in month 2 and employed in month 1) / employed in month 1 
* EU2_1 is (unemployed in month 1 and employed in month2) / employed in month 2 

* 

foreach x in 7 8 {

use Data/match_merge_mis`x', clear 
bys gestfips hrhhid hrhhid2 line: gen dup1 = _n
drop if dup1 > 1 
drop dup1 

save Data/match_merge_mis`x', replace 

} // NOTE: Some duplicates in months 7, 8. Code keeps 1 obs per duplicate set. 

*

forvalues x = 1/7 {
	
preserve 

local y = `x' + 1 

use Data/match_merge_mis`x'.dta, clear 

merge 1:1 gestfips hrhhid hrhhid2 line using Data/match_merge_mis`y' , keep(3)
drop _merge 
drop if line == -1 // Drops double non-responding households 
drop if status`x' == -1 // Drops those who don't answer the LF question 
drop if status`y' == -1 // Same as above 

gen basic_status`x' = 0 
replace basic_status`x' = 1 if status`x' == 1 | status`x' == 2 // e.g. employed
replace basic_status`x' = 2 if status`x' == 3 | status`x' == 4 // e.g. unemployed 
replace basic_status`x' = 3 if status`x' >= 5 & status`x' <= 7 // e.g. NILF 

gen basic_status`y' = 0 
replace basic_status`y' = 1 if status`y' == 1 | status`y' == 2 // e.g. employed
replace basic_status`y' = 2 if status`y' == 3 | status`y' == 4 // e.g. unemployed 
replace basic_status`y' = 3 if status`y' >= 5 & status`y' <= 7 // e.g. NILF 

* Forward Looking Flows 

quietly count if basic_status`x' == 1 
scalar E`x' = r(N) 

quietly count if basic_status`x' == 2 
scalar U`x' = r(N) 

quietly count if basic_status`x' == 3 
scalar N`x' = r(N) 

* EE
quietly count if basic_status`x' == 1 & basic_status`y' == 1 
gen EE`x'_`y' = r(N) / E`x'

* EU 
quietly count if basic_status`x' == 1 & basic_status`y' == 2
gen EU`x'_`y' = r(N) / E`x'

* EN
quietly count if basic_status`x' == 1 & basic_status`y' == 3 
gen EN`x'_`y' = r(N) / E`x'

* UE
quietly count if basic_status`x' == 2 & basic_status`y' == 1
gen UE`x'_`y' = r(N) / U`x'

* UU 
quietly count if basic_status`x' == 2 & basic_status`y' == 2
gen UU`x'_`y' = r(N) / U`x'

* UN 
quietly count if basic_status`x' == 2 & basic_status`y' == 3
gen UN`x'_`y' = r(N) / U`x'

* NE 
quietly count if basic_status`x' == 3 & basic_status`y' == 1
gen NE`x'_`y' = r(N) / N`x'

* NU 
quietly count if basic_status`x' == 3 & basic_status`y' == 2
gen NU`x'_`y' = r(N) / N`x'

* NN 
quietly count if basic_status`x' == 3 & basic_status`y' == 3
gen NN`x'_`y' = r(N) / N`x'

* 

* Backward Looking Flows 

quietly count if basic_status`y' == 1 
scalar E`y' = r(N) 

quietly count if basic_status`y' == 2 
scalar U`y' = r(N) 

quietly count if basic_status`y' == 3 
scalar N`y' = r(N) 

* EE 
quietly count if basic_status`y' == 1 & basic_status`x' == 1
gen EE`y'_`x' = r(N) / E`y' 

* EU (NOTE: EU2_1 means employed in month 2 and unemployed in month 1.)  
* --> Definition counterintuitive, but internally consistent.

quietly count if basic_status`y' == 1 & basic_status`x' == 2
gen EU`y'_`x' = r(N) / E`y'

* EN 
quietly count if basic_status`y' == 1 & basic_status`x' == 3
gen EN`y'_`x' = r(N) / E`y' 

* UE 
quietly count if basic_status`y' == 2 & basic_status`x' == 1
gen UE`y'_`x' = r(N) / U`y'

* UU 
quietly count if basic_status`y' == 2 & basic_status`x' == 2
gen UU`y'_`x' = r(N) / U`y' 

* UN 
quietly count if basic_status`y' == 2 & basic_status`x' == 3
gen UN`y'_`x' = r(N) / U`y' 

* NE 
quietly count if basic_status`y' == 3 & basic_status`x' == 1
gen NE`y'_`x' = r(N) / N`y' 

* NU 
quietly count if basic_status`y' == 3 & basic_status`x' == 2
gen NU`y'_`x' = r(N) / N`y' 

* NN 
quietly count if basic_status`y' == 3 & basic_status`x' == 3
gen NN`y'_`x' = r(N) / N`y' 

*

collapse (mean) EE`x'_`y' EU`x'_`y'  EN`x'_`y'  UE`x'_`y' UU`x'_`y' ///
	UN`x'_`y' NE`x'_`y' NU`x'_`y' NN`x'_`y' EE`y'_`x' EU`y'_`x' EN`y'_`x' ///
	UE`y'_`x' UU`y'_`x' UN`y'_`x' NE`y'_`x' NU`y'_`x' NN`y'_`x' 

foreach z in EE EU EN UE UU UN NE NU NN { 

rename `z'`x'_`y' `z'for
rename `z'`y'_`x' `z'back

}

gen misA = `x' 
gen misB = `y' 

tempfile temp`x' 
save `temp`x'' , replace 

restore 

append using `temp`x''

}

order misA misB 
sort misA

save Data/flows_raw.dta, replace
 
* 

** Estimating Flows while allowing for different flows in different years 
** Addresses cyclicality of flows  

* 

forvalues year = 1998/2020 {

clear 

forvalues x = 1/7 { 
	
if `year' < 2020 | `x' != 4 { 
	* Those in survey month 4 in 2020 haven't had their MIS 5 released yet 

preserve 

local y = `x' + 1 

use Data/match_merge_mis`x'.dta, clear 
keep if int(date`x'/100) == `year' 
drop if line == -1 // Drops non-responding households
drop if status`x' == -1 // Drops those who don't answer the LF question in MIS x 

merge 1:1 gestfips hrhhid hrhhid2 line using Data/match_merge_mis`y' , keep(3)
drop _merge 
drop if status`y' == -1 // Drops those who don't answer the LF question in MIS y 

gen basic_status`x' = 0 
replace basic_status`x' = 1 if status`x' == 1 | status`x' == 2 // e.g. employed
replace basic_status`x' = 2 if status`x' == 3 | status`x' == 4 // e.g. unemployed 
replace basic_status`x' = 3 if status`x' >= 5 & status`x' <= 7 // e.g. NILF 

gen basic_status`y' = 0 
replace basic_status`y' = 1 if status`y' == 1 | status`y' == 2 // e.g. employed
replace basic_status`y' = 2 if status`y' == 3 | status`y' == 4 // e.g. unemployed 
replace basic_status`y' = 3 if status`y' >= 5 & status`y' <= 7 // e.g. NILF 

* Forward Looking Flows 

quietly count if basic_status`x' == 1 
scalar E`x' = r(N) 

quietly count if basic_status`x' == 2 
scalar U`x' = r(N) 

quietly count if basic_status`x' == 3 
scalar N`x' = r(N) 

* EE
quietly count if basic_status`x' == 1 & basic_status`y' == 1 
gen EE`x'_`y' = r(N) / E`x'

* EU 
quietly count if basic_status`x' == 1 & basic_status`y' == 2
gen EU`x'_`y' = r(N) / E`x'

* EN
quietly count if basic_status`x' == 1 & basic_status`y' == 3 
gen EN`x'_`y' = r(N) / E`x'

* UE
quietly count if basic_status`x' == 2 & basic_status`y' == 1
gen UE`x'_`y' = r(N) / U`x'

* UU 
quietly count if basic_status`x' == 2 & basic_status`y' == 2
gen UU`x'_`y' = r(N) / U`x'

* UN 
quietly count if basic_status`x' == 2 & basic_status`y' == 3
gen UN`x'_`y' = r(N) / U`x'

* NE 
quietly count if basic_status`x' == 3 & basic_status`y' == 1
gen NE`x'_`y' = r(N) / N`x'

* NU 
quietly count if basic_status`x' == 3 & basic_status`y' == 2
gen NU`x'_`y' = r(N) / N`x'

* NN 
quietly count if basic_status`x' == 3 & basic_status`y' == 3
gen NN`x'_`y' = r(N) / N`x'

* 

* Backward Looking Flows 

quietly count if basic_status`y' == 1 
scalar E`y' = r(N) 

quietly count if basic_status`y' == 2 
scalar U`y' = r(N) 

quietly count if basic_status`y' == 3 
scalar N`y' = r(N) 

* EE 
quietly count if basic_status`y' == 1 & basic_status`x' == 1
gen EE`y'_`x' = r(N) / E`y' 

* EU (NOTE: EU2_1 means employed in month 2 and unemployed in month 1.)  
* --> Definition counterintuitive, but internally consistent.
quietly count if basic_status`y' == 1 & basic_status`x' == 2
gen EU`y'_`x' = r(N) / E`y'

* EN 
quietly count if basic_status`y' == 1 & basic_status`x' == 3
gen EN`y'_`x' = r(N) / E`y' 

* UE 
quietly count if basic_status`y' == 2 & basic_status`x' == 1
gen UE`y'_`x' = r(N) / U`y'

* UU 
quietly count if basic_status`y' == 2 & basic_status`x' == 2
gen UU`y'_`x' = r(N) / U`y' 

* UN 
quietly count if basic_status`y' == 2 & basic_status`x' == 3
gen UN`y'_`x' = r(N) / U`y' 

* NE 
quietly count if basic_status`y' == 3 & basic_status`x' == 1
gen NE`y'_`x' = r(N) / N`y' 

* NU 
quietly count if basic_status`y' == 3 & basic_status`x' == 2
gen NU`y'_`x' = r(N) / N`y' 

* NN 
quietly count if basic_status`y' == 3 & basic_status`x' == 3
gen NN`y'_`x' = r(N) / N`y' 

*

collapse (mean) EE`x'_`y' EU`x'_`y'  EN`x'_`y'  UE`x'_`y' UU`x'_`y' ///
	UN`x'_`y' NE`x'_`y' NU`x'_`y' NN`x'_`y' EE`y'_`x' EU`y'_`x' EN`y'_`x' ///
	UE`y'_`x' UU`y'_`x' UN`y'_`x' NE`y'_`x' NU`y'_`x' NN`y'_`x' 

foreach z in EE EU EN UE UU UN NE NU NN { 

rename `z'`x'_`y' `z'for
rename `z'`y'_`x' `z'back

}

gen misA = `x' 
gen misB = `y' 

tempfile temp`x' 
save `temp`x'' , replace 

restore 

append using `temp`x''
di "Year: `year' MIS: `x'" 

}
}

tempfile flows_`year' 
save `flows_`year'' , replace 

} 

* Aggregating All Years Into One Data Frame 

clear
gen date = . 
save Data/flows_by_year.dta, replace

forvalues year = 1998/2020 { 

use `flows_`year'' , clear 
gen year = `year' 
append using Data/flows_by_year
save Data/flows_by_year, replace 

}

drop date 
order year misA misB 
sort year misA 
save Data/flows_by_year, replace 

*

foreach z in EE EU EN UE UU UN NE NU NN { 

forvalues x = 1/7 { 

local y = `x' + 1 

gen `z'`x'_`y' = `z'for if misA == `x' 
egen max_`z'`x'_`y' = max(`z'`x'_`y') , by(year) 
drop `z'`x'_`y' 
rename max_`z'`x'_`y' `z'`x'_`y'

gen `z'`y'_`x' = `z'back if misB == `y' 
egen max_`z'`y'_`x' = max(`z'`y'_`x') , by(year) 
drop `z'`y'_`x'
rename max_`z'`y'_`x' `z'`y'_`x' 

}

drop `z'for `z'back 
 
} 

collapse (mean) E* U* N* , by(year) 

save Data/flows_by_year_wide , replace 


