*** How Does the Dramatic Rise of CPS Nonresponse Impact Labor Market Indicators? 
*** Bernhardt, Munro, Wolcott 
*** Journal of Applied Econometrics 
*** 2023 

*** flows_and_corrections3.do

** Builds off of flows_and_corrections1.do and flows_and_corrections2.do 
** Goals: Continue the corrections, but correct for a larger group of people 
** (a) Correct for all-type A's by manufacturing "rougue weights" 
** (b) Robustness test for distribution of NR between matched & unmatched 
** (c) Use total NR corrections in addition to flows 

*

** (a) Rogue Weights 
* NOTE: _rw indicates "rogue weight" corrections 

clear 
global month = 199802  

while $month <= 202008 { 

global month_prev = $month - 1 
global month_next = $month + 1 

if ($month_prev / 100) == int($month_prev / 100) { 
global month_prev = $month_prev - 88 
}

if ($month_next - 13)/100 == int(($month_next - 13)/100) {
    global month_next = $month_next + 88
    }
	
***

quietly do Stata-Code/Function-Scripts/flows3_flows_rw_corr.do 

***

global month = $month + 1 

if ($month - 13)/100 == int(($month - 13)/100) {
    global month = $month + 88	
	di int($month/100)-1 " Finished"
    }
}

* 

gen date_num = date - int(date/100)*100
replace date_num = date_num + int(date/100)*12 - 1998*12
gen mdate = m(1998m1) + date_num - 1
drop date_num 

tsset mdate, m 

line u* mdate 
line lf* mdate
line emp* mdate 

* 

rename u* u*_rw
rename lf* lf*_rw
rename emp* emp*_rw

foreach corr in raw naive flows { 

label variable unemployment_`corr'_rw "Unemployment `corr' RW"
label variable lf_part_`corr'_rw "LF Part `corr' RW" 
label variable emp_pop_`corr'_rw "Emp Pop `corr' RW" 

}

merge 1:1 date using Data/labor_force_corrections 

foreach corr in raw naive flows { 

label variable unemployment_`corr' "Unemployment `corr' "
label variable lf_part_`corr' "LF Part `corr' " 
label variable emp_pop_`corr' "Emp Pop `corr' " 

}


line unemployment_raw unemployment_flows unemployment_flows_rw mdate
line lf_part_raw lf_part_flows lf_part_flows_rw mdate  
line emp_pop_raw emp_pop_flows emp_pop_flows_rw mdate 


save Data/labor_force_corrections_rw.dta, replace 


