*** How Does the Dramatic Rise of CPS Nonresponse Impact Labor Market Indicators? 
*** Bernhardt, Munro, Wolcott 
*** Journal of Applied Econometrics 
*** 2023 

*** flows_output_generation.do
*** Creates paper Figure 3: Key Labor Market Indicators (Line 93) 

clear 

**********************************************************************
** Define globals 
**********************************************************************

global INDATA  "$IS_dir/Data" 
global OUTDATA "$IS_dir/Graphs"  

**********************************************************************
** Loading data
**********************************************************************

use "$INDATA/labor_force_corrections_rw", clear

**********************************************************************
** Creating Correction Graph
**********************************************************************

** Smoothing 

tssmooth ma lf_part_raw_ma= lf_part_raw, window(11 1)
tssmooth ma lf_part_flows_ma= lf_part_flows, window(11 1)
tssmooth ma lf_part_flows_rw_ma=lf_part_flows_rw, window(11 1)
tssmooth ma unemployment_raw_ma= unemployment_raw, window(11 1)
tssmooth ma unemployment_flows_ma= unemployment_flows, window(11 1)
tssmooth ma unemployment_flows_rw_ma=unemployment_flows_rw, window(11 1)
tssmooth ma emp_pop_raw_ma= emp_pop_raw, window(11 1)
tssmooth ma emp_pop_flows_ma=emp_pop_flows, window(11 1)
tssmooth ma emp_pop_flows_rw_ma=emp_pop_flows_rw, window(11 1)

**Differences
gen diff_LF= lf_part_flows_rw_ma - lf_part_raw_ma
gen diff_EP = emp_pop_flows_rw_ma - emp_pop_raw_ma
gen diff_U = unemployment_flows_rw_ma - unemployment_raw_ma


**Sample (2020 data incomplete)
keep if year>1998 & year<2020

**************************************************************
** Graphing for Paper--Combining main figures
**************************************************************
set scheme s2color

line lf_part_raw_ma lf_part_flows_ma lf_part_flows_rw_ma mdate, ///
lcolor("black" "blue" "red") lpattern("l" "-." "_") ///
subtitle("Labor Force Participation Rate", ring(0) pos(1) nobexpand size(medsmall)) ///
ytitle("") xtitle(" ") ylabel(.62 (.01) .67, angle(0)) yscale(range(.62 .67))  ///
xtitle(" ") tlabel(2000m1 (60) 2020m1) xla(,ang(0)) ///
legend(order( 1 "Raw Data" 2 "Flows Correction" 3 "Flows Correction & Reweighting") position(8) ring(0) cols(1) region(fcolor(none) lstyle(none))) ///
plotregion(fcolor(white)) graphregion(fcolor(white) lcolor(white))
graph save "${OUTDATA}/Corrections_LF.gph", replace

line emp_pop_raw_ma emp_pop_flows_ma emp_pop_flows_rw_ma mdate, ///
lcolor("black" "blue" "red") lpattern("l" "-." "_") ///
subtitle("Employment-Population Ratio", ring(0) pos(1) nobexpand size(medsmall)) ///
title("") xtitle(" ") ylabel(.59 (.01) .65, angle(0)) leg(off) ///
xtitle("") tlabel(2000m1 (60) 2020m1) xla(,ang(0)) ///
legend(order( 1 "Raw Data" 2 "Flows Correction" 3 "Flows Correction & Reweighting") position(1) ring(0) cols(1)) ///
plotregion(fcolor(white)) graphregion(fcolor(white) lcolor(white))
graph save "${OUTDATA}/Corrections_EP.gph", replace

line unemployment_raw_ma unemployment_flows_ma unemployment_flows_rw_ma mdate, ///
lcolor("black" "blue" "red") lpattern("l" "-." "_") ///
subtitle("Unemployment Rate", ring(0) pos(1) nobexpand size(medsmall)) ///
title("") xtitle(" ") ylabel(.03 (.01) .09, angle(0)) yscale(range(.03 .09)) leg(off) ///
xtitle(" ") tlabel(2000m1 (60) 2020m1) xla(,ang(0)) ///
legend(order( 1 "Raw Data" 2 "Flows Correction" 3 "Flows Correction & Reweighting"  4) position(8) ring(0) cols(1)) ///
plotregion(fcolor(white)) graphregion(fcolor(white) lcolor(white))
graph save "${OUTDATA}/Corrections_U.gph", replace

graph combine  "${OUTDATA}/Corrections_LF.gph" "${OUTDATA}/Corrections_EP.gph" "${OUTDATA}/Corrections_U.gph", rows(3) ysize(8) 
graph export "${OUTDATA}/MainFigs_combined.eps", replace 


