*** How Does the Dramatic Rise of CPS Nonresponse Impact Labor Market Indicators? 
*** Bernhardt, Munro, Wolcott 
*** Journal of Applied Econometrics 
*** 2023 

*** mis_separate_prepare.do 
*** Generates files containing all HH of a particular month in sample 
*** Outputs files match_merge_mis1.dta through match_merge_mis8.dta 

cd "$IS_dir"

clear 

forvalues mis = 1/8 { 
	***
	
local x = 199801

cap rm Data/match_merge_mis`mis'.dta // Deletes existing copy to avoid error
clear 

while `x' <= 202009 {
	
	preserve 

use Data/cpsb`x'.dta , clear 
keep if mis == `mis' // Keeps relevant month in sample observations 
gen date = `x'

tempfile temp`x'
save `temp`x'' , replace  

	restore 

append using `temp`x''
	
	*** 

local x = `x' + 1
if (`x'-13)/100 == int((`x'-13)/100) {
    local x = `x' + 88
    noisily display (`x'-1)/100 , `mis'
	}
	}
		
		*** 

gen date`mis' = date 
cap rename county1 county_ 

foreach var in ///
 status dur fweight lweight llind mar ind occu ind_recode occu_recode ///
	employ_type non_farm PWCMPWGT HRSAMPLE age PEHSPNON PELKLWO race sex PRSJMJ PREMP educ ///
	HRINTSTA HUINTTYP fam_income HETENURE HUTYPEA HUTYPEB HUTYPEC {
		
		rename `var' `var'`mis'
	}

	*** 
	
	gen date_num = date - int(date/100)*100
	replace date_num = date_num + int(date/100)*12 - 1998*12
	
	if `mis' <= 4 { 
		gen date_num1 = date_num - `mis' + 1 
		gen date_num2 = date_num - `mis' + 2
		gen date_num3 = date_num - `mis' + 3
		gen date_num4 = date_num - `mis' + 4
		gen date_num5 = date_num - `mis' + 5 + 8 
		gen date_num6 = date_num - `mis' + 6 + 8 
		gen date_num7 = date_num - `mis' + 7 + 8 
		gen date_num8 = date_num - `mis' + 8 + 8 
	}
	
	if `mis' >= 5 { 
		gen date_num1 = date_num - `mis' + 1 - 8 
		gen date_num2 = date_num - `mis' + 2 - 8 
		gen date_num3 = date_num - `mis' + 3 - 8 
		gen date_num4 = date_num - `mis' + 4 - 8 
		gen date_num5 = date_num - `mis' + 5  
		gen date_num6 = date_num - `mis' + 6 
		gen date_num7 = date_num - `mis' + 7 
		gen date_num8 = date_num - `mis' + 8 
	}
	
	forvalues x = 1/8{
		gen mdate`x' = m(1998m1) + date_num`x' - 1 
		format mdate`x' %tm 
	}

	drop date_num*
	
	sleep 5000
save Data/match_merge_mis`mis'.dta, replace 
	sleep 5000

	*** 
}   

* 

** Special Edits 

use Data/match_merge_mis7 , clear 

bys gestfips hrhhid hrhhid2 line: gen count1 = _n 
egen max_count1 = max(count1) , by(gestfips hrhhid hrhhid2 line)

drop if max_count1 == 2 & date == 200501
drop *_count1

sleep 5000
save Data/match_merge_mis7 , replace 

* 

use Data/match_merge_mis8 , clear 

bys gestfips hrhhid hrhhid2 line: gen count1 = _n 
egen max_count1 = max(count1) , by(gestfips hrhhid hrhhid2 line)

drop if max_count1 == 2 & date == 200501
drop *_count1 

sleep 5000
save Data/match_merge_mis8 , replace 
